@@ -549,21 +549,25 @@ static void o_net_consolidate_lowlevel (LeptonObject *object,
          object->line->x[1], object->line->y[1]);
 #endif
 
+  GList * del_object_attribs = lepton_object_get_attribs (del_object);
   /* Move any attributes from the deleted object*/
-  if (changed && del_object->attribs != NULL) {
-
+  if (changed && del_object_attribs != NULL)
+  {
     /* Reassign the attached_to pointer on attributes from the del object */
-    a_iter = del_object->attribs;
+    a_iter = del_object_attribs;
     while (a_iter != NULL) {
       a_current = (LeptonObject*) a_iter->data;
-      a_current->attached_to = object;
+      lepton_object_set_attached_to (a_current, object);
       a_iter = g_list_next (a_iter);
     }
 
-    object->attribs = g_list_concat (object->attribs, del_object->attribs);
+    GList *all_attribs = g_list_concat (lepton_object_get_attribs (object),
+                                        del_object_attribs);
+    lepton_object_set_attribs (object, all_attribs);
 
-    /* Don't free del_object->attribs as it's relinked into object's list */
-    del_object->attribs = NULL;
+    /* Don't free del_object's attribute list as it's relinked
+     * into object's list. */
+    lepton_object_set_attribs (del_object, NULL);
   }
 }
 
@@ -658,14 +662,17 @@ o_net_consolidate_segments (LeptonObject *object)
           o_net_consolidate_lowlevel(object, other_object, other_orient);
 
           changed++;
-          if (other_object->selected == TRUE ) {
-            o_selection_remove (page->selection_list, other_object);
+          if (other_object->selected == TRUE)
+          {
+            LeptonSelection *selection = lepton_page_get_selection_list (page);
+            o_selection_remove (selection, other_object);
 
             /* If we're consolidating with a selected object,
              * ensure we select the resulting object.
              */
-            if (object->selected == FALSE) {
-              o_selection_add (page->selection_list, object);
+            if (object->selected == FALSE)
+            {
+              o_selection_add (selection, object);
             }
           }
 
@@ -706,7 +713,7 @@ lepton_net_object_consolidate (LeptonPage *page)
   if (!net_consolidate)
     return;
 
-  iter = s_page_objects (page);
+  iter = lepton_page_objects (page);
 
   while (iter != NULL) {
     o_current = (LeptonObject *)iter->data;
@@ -717,7 +724,7 @@ lepton_net_object_consolidate (LeptonPage *page)
     }
 
     if (status == -1) {
-      iter = s_page_objects (page);
+      iter = lepton_page_objects (page);
       status = 0;
     } else {
       iter = g_list_next (iter);
