@@ -272,6 +272,18 @@ lepton_object_is_text (const LeptonObject *object)
 }
 
 
+/*! \brief Query whether an object is an attribute.
+ *
+ *  \return  TRUE if \a obj is an attribute, FALSE otherwise.
+ */
+gboolean
+lepton_object_is_attrib (const LeptonObject *obj)
+{
+  return (lepton_object_is_text (obj) &&
+          (lepton_text_object_get_name (obj) != NULL));
+}
+
+
 /*! \brief Get the color index of the object
  *
  *  If this function fails, it returns the default color ID.
@@ -306,7 +318,7 @@ lepton_object_get_drawing_color (const LeptonObject *object)
 
   g_return_val_if_fail (object != NULL, default_color_id());
 
-  color = object->selectable ? lepton_object_get_color (object) : LOCK_COLOR;
+  color = lepton_object_get_selectable (object) ? lepton_object_get_color (object) : LOCK_COLOR;
 
   g_return_val_if_fail (color_id_valid (color), default_color_id());
 
@@ -755,6 +767,75 @@ lepton_object_get_whichend (LeptonObject *object)
 }
 
 
+/*! \brief Get object's 'attached_to' field.
+ *
+ *  \par Function Description
+ *  Obtains the 'attached_to' field of the #LeptonObject
+ *  structure.  It defines to what another object the object in
+ *  question is attached to.  \a object is usually an attribute
+ *  while the other object may be component, net, bus, etc.
+ *  \param [in] object The object to obtain the 'attached_to' of.
+ *  \return The value of the 'attached_to' field of the object.
+ */
+LeptonObject*
+lepton_object_get_attached_to (const LeptonObject *object)
+{
+  g_return_val_if_fail (object != NULL, NULL);
+  return object->attached_to;
+}
+
+/*! \brief Set object's 'attached_to' field.
+ *
+ *  \par Function Description
+ *  Set's the 'attached_to' field of the #LeptonObject structure.
+ *  It defines another object to what the object should be
+ *  attached to.  \a object is usually an attribute while the
+ *  other object may be component, net, bus, etc.
+ *  \param [in] object The object to attach.
+ *  \param [in] attached_to The other object.
+ */
+void
+lepton_object_set_attached_to (LeptonObject *object,
+                               LeptonObject *attached_to)
+{
+  g_return_if_fail (object != NULL);
+  object->attached_to = attached_to;
+}
+
+
+/*! \brief Get the list of object's attributes.
+ *
+ *  \par Function Description
+ *  Obtains the list of object's attributes as a GList value.
+ *
+ *  \param [in] object The object to obtain the attribs of.
+ *  \return The GList of attribs of the object.
+ */
+GList*
+lepton_object_get_attribs (const LeptonObject *object)
+{
+  g_return_val_if_fail (object != NULL, NULL);
+  return object->attribs;
+}
+
+
+/*! \brief Set the list of object's attributes.
+ *
+ *  \par Function Description
+ *  Sets the list of object's attributes to the specified GList value.
+ *
+ *  \param [in] object The object to set the attribs for.
+ *  \param [in] attribs The new attrib GList value.
+ */
+void
+lepton_object_set_attribs (LeptonObject *object,
+                           GList *attribs)
+{
+  g_return_if_fail (object != NULL);
+  object->attribs = attribs;
+}
+
+
 /*! \brief Make and return a copy of an object.
  *
  *  \par Function Description
@@ -799,7 +880,7 @@ lepton_object_copy (LeptonObject *object)
       break;
 
     case(OBJ_COMPONENT):
-      new_object = o_component_copy (object);
+      new_object = lepton_component_copy (object);
       break;
 
     case(OBJ_TEXT):
@@ -844,17 +925,23 @@ lepton_object_copy (LeptonObject *object)
 void
 lepton_object_delete (LeptonObject *o_current)
 {
+  GList *primitives = NULL;
+
   if (o_current != NULL) {
     /* If currently attached to a page, remove it from the page */
     if (o_current->page != NULL) {
-      s_page_remove (o_current->page, o_current);
+      lepton_page_remove (o_current->page, o_current);
     }
 
     s_conn_remove_object_connections (o_current);
 
-    if (o_current->attached_to != NULL) {
+    LeptonObject *attachment = lepton_object_get_attached_to (o_current);
+    if (attachment != NULL)
+    {
+      GList *attribs = lepton_object_get_attribs (attachment);
       /* do the actual remove */
-      o_attrib_remove (&o_current->attached_to->attribs, o_current);
+      lepton_object_set_attached_to (o_current, NULL);
+      lepton_object_set_attribs (attachment, g_list_remove (attribs, o_current));
     }
 
     /* printf("sdeleting line\n"); */
@@ -892,18 +979,20 @@ lepton_object_delete (LeptonObject *o_current)
     lepton_fill_free (o_current->fill);
     o_current->fill = NULL;
 
-    /* printf("sdeleting component_basename\n");*/
-    g_free(o_current->component_basename);
-    o_current->component_basename = NULL;
-
     if (o_current->component) {
 
-      if (o_current->component->prim_objs) {
+      primitives = lepton_component_object_get_contents (o_current);
+      if (primitives != NULL)
+      {
         /* printf("sdeleting component's primitive objects\n");*/
-        lepton_object_list_delete (o_current->component->prim_objs);
-        o_current->component->prim_objs = NULL;
+        lepton_object_list_delete (primitives);
+        lepton_component_object_set_contents (o_current, NULL);
       }
 
+      /* The setter below frees the basename of the object if the
+       * given value is NULL. */
+      lepton_component_object_set_basename (o_current, NULL);
+
       g_free(o_current->component);
       o_current->component = NULL;
     }
@@ -1454,12 +1543,17 @@ void
 lepton_object_set_color (LeptonObject *object,
                          int color)
 {
+  GList *primitives = NULL;
+
   g_return_if_fail (object != NULL);
 
   object->color = color;
 
   if (lepton_object_is_component (object) && object->component != NULL)
-    lepton_object_list_set_color (object->component->prim_objs, color);
+  {
+    primitives = lepton_component_object_get_contents (object);
+    lepton_object_list_set_color (primitives, color);
+  }
 }
 
 
@@ -1474,14 +1568,13 @@ lepton_object_set_color (LeptonObject *object,
  * \param [in] object The LeptonObject for which to retrieve the
  *                    parent LeptonPage.
  * \return The LeptonPage which owns \a object or NULL.
- *
- * \sa s_page_append_object() s_page_append() s_page_remove()
  */
 LeptonPage *
 lepton_object_get_page (LeptonObject *object)
 {
-  if (object->parent != NULL) {
-    return lepton_object_get_page (object->parent);
+  LeptonObject *parent = lepton_object_get_parent (object);
+  if (parent != NULL) {
+    return lepton_object_get_page (parent);
   }
   return object->page;
 }
@@ -1501,7 +1594,7 @@ void
 lepton_object_page_set_changed (LeptonObject *object)
 {
   LeptonPage *page = lepton_object_get_page (object);
-  if (page != NULL) page->CHANGED = TRUE;
+  if (page != NULL) lepton_page_set_changed (page, 1);
 }
 
 
@@ -1515,13 +1608,28 @@ lepton_object_page_set_changed (LeptonObject *object)
  * \return The component LeptonObject which owns \a object, or NULL.
  */
 LeptonObject *
-lepton_object_get_parent (LeptonObject *object)
+lepton_object_get_parent (const LeptonObject *object)
 {
   g_return_val_if_fail ((object != NULL), NULL);
 
   return object->parent;
 }
 
+/*! \brief Set a parent object for an object.
+ *
+ * \param [in] object  The object.
+ * \param [in] object  The parent object.
+ */
+void
+lepton_object_set_parent (LeptonObject *object,
+                          LeptonObject *parent)
+{
+  g_return_if_fail (object != NULL);
+
+  object->parent = parent;
+}
+
+
 /* Structure for each entry in a LeptonToplevel's list of
  * registered change notification handlers */
 struct change_notify_entry {
@@ -1762,7 +1870,7 @@ lepton_object_calculate_visible_bounds (LeptonObject *o_current,
     break;
 
   case(OBJ_COMPONENT):
-    if (o_current->component->prim_objs == NULL)
+    if (lepton_component_object_get_contents (o_current) == NULL)
       return 0;
 
     lepton_component_object_calculate_bounds (o_current,
@@ -1865,19 +1973,18 @@ lepton_object_new (int type,
   new_node->stroke = lepton_stroke_new ();
   new_node->fill = lepton_fill_new ();
 
-  new_node->component_basename = NULL;
-  new_node->parent = NULL;
+  lepton_object_set_parent (new_node, NULL);
 
   /* Setup the color */
   lepton_object_set_color (new_node, default_color_id());
   new_node->dont_redraw = FALSE;
-  new_node->selectable = TRUE;
+  lepton_object_set_selectable (new_node, TRUE);
   new_node->selected = FALSE;
 
   new_node->bus_ripper_direction = 0;
 
-  new_node->attribs = NULL;
-  new_node->attached_to = NULL;
+  lepton_object_set_attribs (new_node, NULL);
+  lepton_object_set_attached_to (new_node, NULL);
   new_node->copied_to = NULL;
 
   new_node->pin_type = PIN_TYPE_NET;
