@@ -30,8 +30,6 @@
 /*! Non-zero if the Scheme API has been initialised. */
 static gsize init_called = 0;
 
-SCM_GLOBAL_SYMBOL (edascm_object_state_sym, "object-state");
-
 /*! \brief Scheme API initialisation worker function.
  * \par Function Description
  * Called by edascm_init() with current thread in Guile mode.
@@ -45,12 +43,6 @@ edascm_init_impl (void *data)
                  SCM_UNDEFINED);
   edascm_init_smob ();
   edascm_init_toplevel ();
-  edascm_init_component ();
-  edascm_init_page ();
-  edascm_init_attrib ();
-  edascm_init_config ();
-  edascm_init_closure ();
-  edascm_init_rc ();
   return NULL;
 }
 
