@@ -50,39 +50,6 @@
 
 /* ===================  Public Functions  ====================== */
 
-
-/*! \brief Read a schematic page
- *
- * Reads in a schematic page & calls f_open, which fills out the
- * toplevel structure.
- *
- *  \param toplevel LeptonToplevel structure
- *  \param filename file to be opened
- *  \returns 1 on success, 0 on failure
- */
-int
-s_toplevel_read_page (LeptonToplevel *toplevel,
-                      char *filename)
-{
-  int file_return_code;
-  GError *err = NULL;
-
-  /* Set the new filename */
-  s_page_set_filename (toplevel->page_current, filename);
-
-  /* read in and fill out toplevel using f_open and its callees */
-  file_return_code = f_open (toplevel, toplevel->page_current, filename, &err);
-
-  /* If an error occurred, print message */
-  if (err != NULL) {
-    g_warning ("%s", err->message);
-    g_error_free (err);
-  }
-
-  return file_return_code;
-}
-
-
 /*! \brief Verify the entire design
  *
  * This function loops through all objects in the design looking
@@ -103,7 +70,7 @@ void s_toplevel_verify_design (LeptonToplevel *toplevel)
        p_iter = g_list_next (p_iter)) {
     LeptonPage *p_current = (LeptonPage*) p_iter->data;
 
-    for (o_iter = s_page_objects (p_current);
+    for (o_iter = lepton_page_objects (p_current);
          o_iter != NULL;
          o_iter = g_list_next (o_iter)) {
       LeptonObject *o_current = (LeptonObject*) o_iter->data;
@@ -130,8 +97,8 @@ void s_toplevel_verify_design (LeptonToplevel *toplevel)
  *  \param [in] toplevel  The LeptonToplevel to save pages from.
  *  \return The number of failed tries to save a page.
  */
-gint
-s_page_save_all (LeptonToplevel *toplevel)
+static gint
+save_toplevel_pages (LeptonToplevel *toplevel)
 {
   const GList *iter;
   LeptonPage *p_current;
@@ -143,15 +110,16 @@ s_page_save_all (LeptonToplevel *toplevel)
 
     p_current = (LeptonPage *)iter->data;
 
-    if (f_save (p_current, s_page_get_filename (p_current), NULL)) {
+    if (f_save (p_current, lepton_page_get_filename (p_current), NULL))
+    {
       g_message (_("Saved [%1$s]"),
-                 s_page_get_filename (p_current));
+                 lepton_page_get_filename (p_current));
       /* reset the CHANGED flag of p_current */
-      p_current->CHANGED = 0;
+      lepton_page_set_changed (p_current, 0);
 
     } else {
       g_message (_("Could NOT save [%1$s]"),
-                 s_page_get_filename (p_current));
+                 lepton_page_get_filename (p_current));
       /* increase the error counter */
       status++;
     }
@@ -201,7 +169,7 @@ s_toplevel_save_sheet ()
            "Done writing SHEEET_DATA text back into pr_currnet.\n");
 
   /* Save all pages in design. */
-  s_page_save_all (toplevel);
+  save_toplevel_pages (toplevel);
   s_sheet_data_set_changed (sheet_head, FALSE);
 
   return;
@@ -444,7 +412,7 @@ s_toplevel_sheetdata_to_toplevel (LeptonToplevel *toplevel,
    * from the list during iteration over the list.
    */
   /* NB: g_list_copy doesn't declare its input const, so we cast */
-  copy_list = g_list_copy ((GList *)s_page_objects (page));
+  copy_list = g_list_copy ((GList *) lepton_page_objects (page));
 
   /* Iterate backwards since attributes are attached after their
    * parent objects in the list. Attributes can get deleted during
@@ -509,7 +477,7 @@ s_toplevel_sheetdata_to_toplevel (LeptonToplevel *toplevel,
    * deleted from the list during its iteration.
    */
   /* NB: g_list_copy doesn't declare its input const, so we cast */
-  copy_list = g_list_copy ((GList *)s_page_objects (page));
+  copy_list = g_list_copy ((GList *) lepton_page_objects (page));
 
   for (o_iter = g_list_last (copy_list);
        o_iter != NULL;
@@ -522,7 +490,7 @@ s_toplevel_sheetdata_to_toplevel (LeptonToplevel *toplevel,
     {
       /*  Upon finding a component, here's what to do:
        *  0.  Get refdes of component.
-       *  1.  Loop over prim_objects, looking for pins.
+       *  1.  Loop over primitive objects, looking for pins.
        *  2.  When a pin is found, create refdes:pinnumber pair
        *      used in searching TABLE.
        *  3.  Search TABLE using refdes:pinnumber as key, and get list of
@@ -530,9 +498,10 @@ s_toplevel_sheetdata_to_toplevel (LeptonToplevel *toplevel,
        *  4.  Stick the attribs into the LeptonToplevel data structure.
        */
       temp_uref =  s_attrib_get_refdes(o_current);
-      if ( (temp_uref != NULL) && (o_current->component->prim_objs) ) {    /* make sure object component has a refdes  */
-
-        for (prim_iter = o_current->component->prim_objs;
+      /* Make sure object component has a refdes. */
+      if (temp_uref != NULL)
+      {
+        for (prim_iter = lepton_component_object_get_contents (o_current);
              prim_iter != NULL;
              prim_iter = g_list_next (prim_iter)) {
           LeptonObject *comp_prim_obj = (LeptonObject*) prim_iter->data;
@@ -688,7 +657,7 @@ s_toplevel_update_component_attribs_in_toplevel (LeptonToplevel *toplevel,
 
   /* Now create a complete list of unique attribute names.  This will be used in
   *  the loop below when updating attributes.  */
-  a_iter = o_current->attribs;
+  a_iter = lepton_object_get_attribs (o_current);
   while (a_iter != NULL) {
     a_current = (LeptonObject*) a_iter->data;
     if (lepton_object_is_text (a_current)
@@ -708,8 +677,9 @@ s_toplevel_update_component_attribs_in_toplevel (LeptonToplevel *toplevel,
 #else
       /* might now compile now, but this #if'd out branch isn't being built */
       gint status;
-      status = o_attrib_get_name_value (a_current, &old_attrib_name, &old_attrib_value);
-      if (status == 0) {
+      old_attrib_name = g_strdup (lepton_text_object_get_name (a_current));
+      if (old_attrib_name != NULL)
+      {
         /* Don't put "refdes" or "slot" into list.  Don't put old name=value pair into list if a new
          * one is already in there. */
         if ( (strcmp(old_attrib_name, "refdes") != 0) &&
@@ -719,7 +689,6 @@ s_toplevel_update_component_attribs_in_toplevel (LeptonToplevel *toplevel,
           s_string_list_add_item(complete_comp_attrib_list, &count, old_name_value_pair);
         }
         g_free (old_attrib_name);
-        g_free (old_attrib_value);
       }
  #endif
      g_free(old_name_value_pair);
