@@ -85,6 +85,16 @@ x_window_get_toplevel ()
   return window_toplevel;
 }
 
+static GtkWidget*
+separator_new ()
+{
+#ifdef ENABLE_GTK3
+  return gtk_separator_new (GTK_ORIENTATION_VERTICAL);
+#else
+  return gtk_vseparator_new ();
+#endif
+}
+
 /*! \brief Initialises the toplevel gtksheet
  *
  * This function initializes the toplevel gtksheet stuff.
@@ -145,16 +155,16 @@ x_window_init ()
   GtkWidget* label_name_val = gtk_label_new (_(" Show name and value "));
 
   gtk_box_pack_start (GTK_BOX (marea), label_1, FALSE, TRUE, 0);
-  gtk_box_pack_start (GTK_BOX (marea), gtk_vseparator_new() , FALSE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (marea), separator_new() , FALSE, TRUE, 0);
 
   gtk_box_pack_start (GTK_BOX (marea), label_inv, FALSE, TRUE, 0);
-  gtk_box_pack_start (GTK_BOX (marea), gtk_vseparator_new() , FALSE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (marea), separator_new() , FALSE, TRUE, 0);
 
   gtk_box_pack_start (GTK_BOX (marea), label_val, FALSE, TRUE, 0);
-  gtk_box_pack_start (GTK_BOX (marea), gtk_vseparator_new() , FALSE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (marea), separator_new() , FALSE, TRUE, 0);
 
   gtk_box_pack_start (GTK_BOX (marea), label_name, FALSE, TRUE, 0);
-  gtk_box_pack_start (GTK_BOX (marea), gtk_vseparator_new() , FALSE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (marea), separator_new() , FALSE, TRUE, 0);
 
   gtk_box_pack_start (GTK_BOX (marea), label_name_val, FALSE, TRUE, 0);
 
@@ -539,7 +549,7 @@ x_window_set_title (GList* plist)
 
   if (g_list_length (plist) == 1)
   {
-    const gchar* fpath = s_page_get_filename ((LeptonPage *) plist->data);
+    const gchar* fpath = lepton_page_get_filename ((LeptonPage *) plist->data);
     gchar* fname = g_path_get_basename (fpath);
 
     title = g_strdup_printf ("%s - %s", fname, prog_name);
@@ -616,11 +626,11 @@ lepton_attrib_window ()
        iter = g_list_next (iter)) {
 
     p_local = (LeptonPage*) iter->data;
-    s_toplevel_set_page_current (toplevel, p_local);
+    lepton_toplevel_set_page_current (toplevel, p_local);
 
     /* Now add all items found to the master lists */
-    s_sheet_data_add_master_comp_list_items (s_page_objects (p_local));
-    s_sheet_data_add_master_comp_attrib_list_items (s_page_objects (p_local));
+    s_sheet_data_add_master_comp_list_items (lepton_page_objects (p_local));
+    s_sheet_data_add_master_comp_attrib_list_items (lepton_page_objects (p_local));
 #if 0
     /* Note that this must be changed.  We need to input the entire project
      * before doing anything with the nets because we need to first
@@ -629,8 +639,8 @@ lepton_attrib_window ()
     s_sheet_data_add_master_net_attrib_list_items (p_local->object_list);
 #endif
 
-    s_sheet_data_add_master_pin_list_items (s_page_objects (p_local));
-    s_sheet_data_add_master_pin_attrib_list_items (s_page_objects (p_local));
+    s_sheet_data_add_master_pin_list_items (lepton_page_objects (p_local));
+    s_sheet_data_add_master_pin_attrib_list_items (lepton_page_objects (p_local));
   }     /* end of loop over files     */
 
   /* ---------- Sort the master lists  ---------- */
@@ -662,7 +672,7 @@ lepton_attrib_window ()
     /* only traverse pages which are toplevel */
     if (p_local->page_control == 0) {
       /* adds all components from page to comp_table */
-      s_table_add_toplevel_comp_items_to_comp_table (s_page_objects (p_local));
+      s_table_add_toplevel_comp_items_to_comp_table (lepton_page_objects (p_local));
 #if 0
       /* Note that this must be changed.  We need to input the entire project
        * before doing anything with the nets because we need to first
@@ -673,7 +683,7 @@ lepton_attrib_window ()
 #endif
 
       /* adds all pins from page to pin_table */
-      s_table_add_toplevel_pin_items_to_pin_table (s_page_objects (p_local));
+      s_table_add_toplevel_pin_items_to_pin_table (lepton_page_objects (p_local));
     }
   } /* for loop over pages */
 
