@@ -294,7 +294,13 @@ gschem_toplevel_set_toplevel (GschemToplevel *w_current,
 void
 gschem_toplevel_page_content_changed (GschemToplevel *w_current,
                                       LeptonPage *page);
+void
+schematic_window_active_page_changed (GschemToplevel *w_current);
+
 gboolean
 gschem_toplevel_get_show_hidden_text (GschemToplevel *w_current);
 
+LeptonPage*
+schematic_window_get_active_page (GschemToplevel *w_current);
+
 G_END_DECLS
