@@ -97,8 +97,11 @@ update_magnetic_net_label (GschemBottomWidget *widget, GParamSpec *pspec, gpoint
 
 /* convenience macro - gobject type implementation:
 */
+#ifdef ENABLE_GTK3
+G_DEFINE_TYPE (GschemBottomWidget, gschem_bottom_widget, GTK_TYPE_BOX);
+#else
 G_DEFINE_TYPE (GschemBottomWidget, gschem_bottom_widget, GTK_TYPE_HBOX);
-
+#endif
 
 
 static gboolean
@@ -545,6 +548,17 @@ gschem_bottom_widget_get_magnetic_net_mode (GschemBottomWidget *widget)
 
 
 
+static GtkWidget*
+separator_new ()
+{
+#ifdef ENABLE_GTK3
+  return gtk_separator_new (GTK_ORIENTATION_VERTICAL);
+#else
+  return gtk_vseparator_new ();
+#endif
+}
+
+
 /*! \brief Set grid_snap_widget text
  *
  *  \param  widget  This GschemBottomWidget
@@ -748,7 +762,7 @@ create_snap_info_widget (GschemBottomWidget* widget)
                         LABEL_YPAD);
   gtk_box_pack_start (GTK_BOX (widget), ebox, FALSE, FALSE, 0);
 
-  gtk_box_pack_start (GTK_BOX (widget), gtk_vseparator_new(), FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (widget), separator_new(), FALSE, FALSE, 0);
 
   g_signal_connect (G_OBJECT (ebox),
                     "button-press-event",
@@ -817,7 +831,7 @@ create_grid_size_widget (GschemBottomWidget* widget)
                         LABEL_YPAD);
   gtk_box_pack_start (GTK_BOX (widget), ebox, FALSE, FALSE, 0);
 
-  gtk_box_pack_start (GTK_BOX (widget), gtk_vseparator_new(), FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (widget), separator_new(), FALSE, FALSE, 0);
 
   g_signal_connect (G_OBJECT (ebox),
                     "button-press-event",
@@ -930,11 +944,11 @@ gschem_bottom_widget_init (GschemBottomWidget *widget)
   if (show_mouse_indicators)
   {
     gtk_box_pack_start (GTK_BOX (widget), widget->left_button_label, FALSE, FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (widget), gtk_vseparator_new(), FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (widget), separator_new(), FALSE, FALSE, 0);
     gtk_box_pack_start (GTK_BOX (widget), widget->middle_button_label, FALSE, FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (widget), gtk_vseparator_new(), FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (widget), separator_new(), FALSE, FALSE, 0);
     gtk_box_pack_start (GTK_BOX (widget), widget->right_button_label, FALSE, FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (widget), gtk_vseparator_new(), FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (widget), separator_new(), FALSE, FALSE, 0);
   }
 
 
@@ -942,7 +956,7 @@ gschem_bottom_widget_init (GschemBottomWidget *widget)
   create_grid_size_widget (widget);
 
 
-  separator = gtk_vseparator_new ();
+  separator = separator_new ();
   gtk_box_pack_start (GTK_BOX (widget), separator, FALSE, FALSE, 0);
 
 
@@ -965,7 +979,7 @@ gschem_bottom_widget_init (GschemBottomWidget *widget)
   }
 
 
-  separator = gtk_vseparator_new ();
+  separator = separator_new ();
   gtk_box_pack_start (GTK_BOX (widget), separator, FALSE, FALSE, 0);
 
 
@@ -993,7 +1007,7 @@ gschem_bottom_widget_init (GschemBottomWidget *widget)
   gtk_misc_set_padding (GTK_MISC (widget->status_label), LABEL_XPAD, LABEL_YPAD);
   gtk_box_pack_end (GTK_BOX (widget), widget->status_label, FALSE, FALSE, 0);
 
-  separator = gtk_vseparator_new ();
+  separator = separator_new ();
   gtk_box_pack_start (GTK_BOX (widget), separator, FALSE, FALSE, 0);
 
   g_signal_connect (G_OBJECT (widget),
