@@ -216,8 +216,8 @@ get_page_name (GtkTreeModel *model, GtkTreeIter *piter, gboolean full_path)
                       -1);
   g_assert (page != NULL);
 
-  return full_path ? g_strdup (s_page_get_filename (page))
-                   : g_path_get_basename (s_page_get_filename (page));
+  return full_path ? g_strdup (lepton_page_get_filename (page))
+                   : g_path_get_basename (lepton_page_get_filename (page));
 }
 
 /*! \brief Sets the contents of the name cell in the treeview of dialog.
@@ -755,9 +755,9 @@ x_dialog_close_changed_page (GschemToplevel *w_current, LeptonPage *page)
   LeptonPage *keep_page;
   gboolean result = FALSE;
 
-  g_return_val_if_fail (page != NULL && page->CHANGED, TRUE);
+  g_return_val_if_fail (page != NULL && lepton_page_get_changed (page), TRUE);
 
-  keep_page = w_current->toplevel->page_current;
+  keep_page = schematic_window_get_active_page (w_current);
 
   dialog = GTK_WIDGET (g_object_new (TYPE_CLOSE_CONFIRMATION_DIALOG,
                                      "unsaved-page", page,
@@ -779,11 +779,12 @@ x_dialog_close_changed_page (GschemToplevel *w_current, LeptonPage *page)
 
       case GTK_RESPONSE_YES:
         /* action selected: save */
-        s_page_goto (w_current->toplevel, page);
+        lepton_toplevel_goto_page (gschem_toplevel_get_toplevel (w_current), page);
         gschem_toplevel_page_changed (w_current);
         i_callback_file_save (NULL, w_current);
         /* has the page been really saved? */
-        if (!page->CHANGED) {
+        if (!lepton_page_get_changed (page))
+        {
           result = TRUE;
         }
         /* no, user has cancelled the save and page has changes */
@@ -804,7 +805,7 @@ x_dialog_close_changed_page (GschemToplevel *w_current, LeptonPage *page)
   /* Switch back to the page we were on if it wasn't the one being closed */
   g_return_val_if_fail (keep_page != NULL, result);
   if (keep_page != page) {
-    s_page_goto (w_current->toplevel, keep_page);
+    lepton_toplevel_goto_page (gschem_toplevel_get_toplevel (w_current), keep_page);
     gschem_toplevel_page_changed (w_current);
   }
   return result;
@@ -836,7 +837,7 @@ x_dialog_close_window (GschemToplevel *w_current)
   GList *unsaved_pages, *p_unsaved;
   gboolean ret = FALSE;
 
-  keep_page = toplevel->page_current;
+  keep_page = schematic_window_get_active_page (w_current);
 
   for ( iter = lepton_list_get_glist( toplevel->pages ), unsaved_pages = NULL;
         iter != NULL;
@@ -844,7 +845,8 @@ x_dialog_close_window (GschemToplevel *w_current)
 
     p_current = (LeptonPage*)iter->data;
 
-    if (p_current->CHANGED) {
+    if (lepton_page_get_changed (p_current))
+    {
       unsaved_pages = g_list_append (unsaved_pages, (gpointer)p_current);
     }
   }
@@ -880,12 +882,12 @@ x_dialog_close_window (GschemToplevel *w_current)
              p_unsaved = g_list_next (p_unsaved)) {
           p_current = (LeptonPage*) p_unsaved->data;
 
-          s_page_goto (toplevel, p_current);
+          lepton_toplevel_goto_page (toplevel, p_current);
           gschem_toplevel_page_changed (w_current);
 
           i_callback_file_save (NULL, w_current);
           /* if user cancelled previous, do not close window */
-          ret &= !p_current->CHANGED;
+          ret &= !lepton_page_get_changed (p_current);
         }
         g_list_free (unsaved_pages);
         break;
@@ -903,7 +905,7 @@ x_dialog_close_window (GschemToplevel *w_current)
 
   /* Switch back to the page we were on */
   g_return_val_if_fail (keep_page != NULL, ret);
-  s_page_goto (toplevel, keep_page);
+  lepton_toplevel_goto_page (toplevel, keep_page);
   gschem_toplevel_page_changed (w_current);
 
   return ret;
