@@ -223,7 +223,7 @@ assign_store (GschemFindTextState *state, GSList *objects, gboolean filter_text)
 
     gtk_list_store_append (state->store, &tree_iter);
 
-    basename = g_path_get_basename (s_page_get_filename (object->page));
+    basename = g_path_get_basename (lepton_page_get_filename (object->page));
 
     gtk_list_store_set (state->store,
                         &tree_iter,
@@ -357,7 +357,7 @@ find_objects_using_pattern (GSList *pages,
       continue;
     }
 
-    object_iter = s_page_objects (page);
+    object_iter = lepton_page_objects (page);
 
     while (object_iter != NULL) {
       LeptonObject *object = (LeptonObject*) object_iter->data;
@@ -437,7 +437,7 @@ find_objects_using_regex (GSList *pages,
       continue;
     }
 
-    object_iter = s_page_objects (page);
+    object_iter = lepton_page_objects (page);
 
     while (object_iter != NULL) {
       LeptonObject *object = (LeptonObject*) object_iter->data;
@@ -506,7 +506,7 @@ find_objects_using_substring (GSList *pages,
       continue;
     }
 
-    object_iter = s_page_objects (page);
+    object_iter = lepton_page_objects (page);
 
     while (object_iter != NULL) {
       LeptonObject *object = (LeptonObject*) object_iter->data;
@@ -679,7 +679,7 @@ get_subpages (GschemToplevel *w_current,
 
   g_return_val_if_fail (page != NULL, NULL);
 
-  object_iter = s_page_objects (page);
+  object_iter = lepton_page_objects (page);
 
   while (object_iter != NULL) {
     char *attrib;
