@@ -79,7 +79,7 @@ preview_get_filename (GschemPreview *preview)
 
   g_return_val_if_fail (page != NULL, "");
 
-  return s_page_get_filename (page);
+  return lepton_page_get_filename (page);
 }
 
 
@@ -178,7 +178,7 @@ preview_update (GschemPreview *preview)
   LeptonToplevel *preview_toplevel = preview_page->toplevel;
 
   /* delete old preview */
-  s_page_delete_objects (preview_page);
+  lepton_page_delete_objects (preview_page);
 
   if (preview->active) {
     g_assert ((preview->filename == NULL) || (preview->buffer == NULL));
@@ -197,25 +197,25 @@ preview_update (GschemPreview *preview)
                                        _("Preview Buffer"), &err);
 
       if (err == NULL) {
-        s_page_append_list (preview_page, objects);
+        lepton_page_append_list (preview_page, objects);
       }
       else {
-        s_page_append (preview_page,
-                       lepton_text_object_new (2,
-                                               100,
-                                               100,
-                                               LOWER_MIDDLE,
-                                               0,
-                                               err->message,
-                                               10,
-                                               VISIBLE,
-                                               SHOW_NAME_VALUE));
+        lepton_page_append (preview_page,
+                            lepton_text_object_new (2,
+                                                    100,
+                                                    100,
+                                                    LOWER_MIDDLE,
+                                                    0,
+                                                    err->message,
+                                                    10,
+                                                    VISIBLE,
+                                                    SHOW_NAME_VALUE));
         g_error_free(err);
       }
     }
   }
 
-  if (world_get_object_glist_bounds (s_page_objects (preview_page),
+  if (world_get_object_glist_bounds (lepton_page_objects (preview_page),
                                      /* Do not include hidden text. */
                                      FALSE,
                                      &left, &top,
@@ -326,8 +326,8 @@ gschem_preview_init (GschemPreview *preview)
   preview->buffer   = NULL;
 
   gschem_page_view_set_page (GSCHEM_PAGE_VIEW (preview),
-                             s_page_new (preview->preview_w_current->toplevel,
-                                         "preview"));
+                             lepton_page_new (preview->preview_w_current->toplevel,
+                                              "preview"));
 
   gtk_widget_set_events (GTK_WIDGET (preview),
                          GDK_EXPOSURE_MASK |
