@@ -445,7 +445,6 @@ GschemSelectionAdapter*
 gschem_toplevel_get_selection_adapter (GschemToplevel *w_current)
 {
   g_return_val_if_fail (w_current != NULL, NULL);
-  g_return_val_if_fail (w_current->toplevel != NULL, NULL);
 
   if (w_current->selection_adapter == NULL) {
     w_current->selection_adapter = gschem_selection_adapter_new ();
@@ -458,9 +457,10 @@ gschem_toplevel_get_selection_adapter (GschemToplevel *w_current)
 
     gschem_selection_adapter_set_toplevel (w_current->selection_adapter, w_current->toplevel);
 
-    if (w_current->toplevel->page_current != NULL) {
+    LeptonPage *active_page = schematic_window_get_active_page (w_current);
+    if (active_page != NULL) {
       gschem_selection_adapter_set_selection (w_current->selection_adapter,
-                                              w_current->toplevel->page_current->selection_list);
+                                              active_page->selection_list);
     } else {
       gschem_selection_adapter_set_selection (w_current->selection_adapter,
                                               NULL);
@@ -667,10 +667,12 @@ void
 gschem_toplevel_page_changed (GschemToplevel *w_current)
 {
   g_return_if_fail (w_current != NULL);
-  g_return_if_fail (w_current->toplevel != NULL);
 
-  if ((w_current->selection_adapter != NULL) && (w_current->toplevel->page_current != NULL)) {
-    gschem_selection_adapter_set_selection (w_current->selection_adapter, w_current->toplevel->page_current->selection_list);
+  LeptonPage *active_page = schematic_window_get_active_page (w_current);
+  if ((w_current->selection_adapter != NULL) && (active_page != NULL))
+  {
+    gschem_selection_adapter_set_selection (w_current->selection_adapter,
+                                            active_page->selection_list);
   }
 }
 
@@ -690,12 +692,29 @@ gschem_toplevel_page_content_changed (GschemToplevel *w_current,
   g_return_if_fail (page != NULL);
   g_return_if_fail (w_current != NULL);
 
-  page->CHANGED = 1;
+  lepton_page_set_changed (page, 1);
 
   page_select_widget_update (w_current);
 }
 
 
+/*! \brief Temp function to notify of active page content change.
+ *
+ *  This function is temporary until library functions can emit
+ *  signals.
+ *
+ *  \param [in] w_current The current schematic window.
+ */
+void
+schematic_window_active_page_changed (GschemToplevel *w_current)
+{
+  g_return_if_fail (w_current != NULL);
+  LeptonPage *active_page = schematic_window_get_active_page (w_current);
+
+  gschem_toplevel_page_content_changed (w_current, active_page);
+}
+
+
 /*! \brief Set the libgeda toplevel for this gschem toplevel
  *
  *  \param [in] w_current This gschem toplevel
@@ -717,14 +736,9 @@ gschem_toplevel_set_toplevel (GschemToplevel *w_current,
 static void
 handle_undo (GschemToplevel *w_current)
 {
-  LeptonToplevel *toplevel;
-
   g_return_if_fail (w_current != NULL);
 
-  toplevel = gschem_toplevel_get_toplevel (w_current);
-  g_return_if_fail (toplevel != NULL);
-
-  gschem_toplevel_page_content_changed (w_current, toplevel->page_current);
+  schematic_window_active_page_changed (w_current);
   o_undo_savestate_old (w_current, UNDO_ALL);
 }
 
@@ -741,12 +755,8 @@ notify_options (GschemToplevel *w_current)
 
   /* Events can occur before the drawing area is created */
 
-  if (w_current->drawing_area != NULL) {
-    /* maybe remove those two lines
-     * gschem_toplevel_get_toplevel (w_current)->page_current->CHANGED=1;
-     * o_undo_savestate_old(w_current, UNDO_ALL);
-     */
-
+  if (w_current->drawing_area != NULL)
+  {
     i_update_grid_info (w_current);
     gschem_page_view_invalidate_all (gschem_toplevel_get_current_page_view (w_current));
   }
@@ -800,3 +810,20 @@ gschem_toplevel_get_show_hidden_text (GschemToplevel *w_current)
      return FALSE in such cases. */
   return (view == NULL) ? FALSE : gschem_page_view_get_show_hidden_text (view);
 }
+
+
+/*! \brief Get the active page for this schematic window.
+ *
+ *  \param [in] w_current The schematic window.
+ *  \return The currently active page.
+ */
+LeptonPage*
+schematic_window_get_active_page (GschemToplevel *w_current)
+{
+  g_return_val_if_fail (w_current != NULL, NULL);
+
+  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
+  g_return_val_if_fail (toplevel != NULL, NULL);
+
+  return toplevel->page_current;
+}
