@@ -47,7 +47,7 @@ i_callback_file_new (GtkWidget *widget, gpointer data)
   g_return_if_fail (page != NULL);
 
   x_window_set_current_page (w_current, page);
-  g_message (_("New page created [%1$s]"), s_page_get_filename (page));
+  g_message (_("New page created [%1$s]"), lepton_page_get_filename (page));
 }
 
 
@@ -70,7 +70,7 @@ i_callback_file_new_window (GtkWidget* widget, gpointer data)
 
   x_window_set_current_page (w_current, page);
 
-  g_message (_("New Window created [%1$s]"), s_page_get_filename (page));
+  g_message (_("New Window created [%1$s]"), lepton_page_get_filename (page));
 }
 
 /*! \todo Finish function documentation!!!
@@ -135,7 +135,7 @@ i_callback_file_script (GtkWidget *widget, gpointer data)
     gchar* filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
 
     g_message (_("Executing Guile script [%s]"), filename);
-    g_read_file (w_current->toplevel, filename, NULL);
+    g_read_file (gschem_toplevel_get_toplevel (w_current), filename, NULL);
 
     g_free (filename);
   }
@@ -161,8 +161,7 @@ i_callback_file_save (GtkWidget *widget, gpointer data)
   GschemToplevel *w_current = GSCHEM_TOPLEVEL (data);
   g_return_if_fail (w_current != NULL);
 
-  LeptonToplevel* toplevel = gschem_toplevel_get_toplevel (w_current);
-  LeptonPage* page = toplevel->page_current;
+  LeptonPage* page = schematic_window_get_active_page (w_current);
 
   if (page == NULL) {
     return;
@@ -176,7 +175,7 @@ i_callback_file_save (GtkWidget *widget, gpointer data)
   else
   {
     /* save page: */
-    const gchar* fname = s_page_get_filename (page);
+    const gchar* fname = lepton_page_get_filename (page);
     x_window_save_page (w_current, page, fname);
   }
 
@@ -212,7 +211,7 @@ i_callback_file_save_all (GtkWidget *widget, gpointer data)
     else
     {
       /* save page: */
-      const gchar* fname = s_page_get_filename (page);
+      const gchar* fname = lepton_page_get_filename (page);
       res = x_window_save_page (w_current, page, fname);
       result = result && res;
     }
@@ -252,8 +251,7 @@ i_callback_file_save_as (GtkWidget *widget, gpointer data)
 
   g_return_if_fail (w_current != NULL);
 
-  LeptonToplevel* toplevel = gschem_toplevel_get_toplevel (w_current);
-  LeptonPage* page = toplevel->page_current;
+  LeptonPage* page = schematic_window_get_active_page (w_current);
 
   x_fileselect_save (w_current, page, NULL);
 }
@@ -336,7 +334,7 @@ i_callback_edit_undo (GtkWidget *widget, gpointer data)
    *
    * It "might" be nice to sub-undo rotates / zoom changes
    * made whilst moving components, but when the undo code
-   * hits s_page_delete(), the place list objects are free'd.
+   * hits lepton_page_delete(), the place list objects are free'd.
    * Since they are also contained in the schematic page, a
    * crash occurs when the page objects are free'd.
    * */
@@ -555,7 +553,9 @@ i_callback_edit_edit (GtkWidget *widget, gpointer data)
 
   g_return_if_fail (w_current != NULL);
 
-  o_edit(w_current, lepton_list_get_glist( gschem_toplevel_get_toplevel (w_current)->page_current->selection_list ) );
+  LeptonPage *active_page = schematic_window_get_active_page (w_current);
+
+  o_edit(w_current, lepton_list_get_glist (active_page->selection_list));
 }
 
 /*! \todo Finish function documentation!!!
@@ -618,22 +618,20 @@ i_callback_edit_rotate_90 (GtkWidget *widget, gpointer data)
   gint wx, wy;
   GList *object_list;
   GschemToplevel *w_current = NULL;
-  GschemPageView *view = NULL;
-  LeptonPage* page = NULL;
+  LeptonPage* active_page = NULL;
 
   w_current = GSCHEM_TOPLEVEL (data);
   g_return_if_fail (w_current != NULL);
 
-  view = (gschem_toplevel_get_current_page_view (w_current));
-  g_return_if_fail (view != NULL);
+  active_page = schematic_window_get_active_page (w_current);
 
-  page = (gschem_page_view_get_page (view));
-
-  if (page == NULL) {
+  if (active_page == NULL)
+  {
     return;
   }
 
-  if (w_current->inside_action && (page->place_list != NULL)) {
+  if (w_current->inside_action && (active_page->place_list != NULL))
+  {
     o_place_rotate (w_current);
     return;
   }
@@ -645,7 +643,7 @@ i_callback_edit_rotate_90 (GtkWidget *widget, gpointer data)
 
   o_redraw_cleanstates(w_current);
 
-  object_list = lepton_list_get_glist( gschem_toplevel_get_toplevel (w_current)->page_current->selection_list );
+  object_list = lepton_list_get_glist (active_page->selection_list);
 
   if (object_list) {
     /* Allow o_rotate_world_update to redraw the objects */
@@ -664,22 +662,18 @@ i_callback_edit_mirror (GtkWidget *widget, gpointer data)
   gint wx, wy;
   GList *object_list;
   GschemToplevel *w_current = NULL;
-  GschemPageView *view = NULL;
-  LeptonPage* page = NULL;
+  LeptonPage* active_page = NULL;
 
   w_current = GSCHEM_TOPLEVEL (data);
   g_return_if_fail (w_current != NULL);
 
-  view = (gschem_toplevel_get_current_page_view (w_current));
-  g_return_if_fail (view != NULL);
+  active_page = schematic_window_get_active_page (w_current);
 
-  page = (gschem_page_view_get_page (view));
-
-  if (page == NULL) {
+  if (active_page == NULL) {
     return;
   }
 
-  if (w_current->inside_action && (page->place_list != NULL)) {
+  if (w_current->inside_action && (active_page->place_list != NULL)) {
     o_place_mirror (w_current);
     return;
   }
@@ -691,7 +685,7 @@ i_callback_edit_mirror (GtkWidget *widget, gpointer data)
 
   o_redraw_cleanstates(w_current);
 
-  object_list = lepton_list_get_glist( gschem_toplevel_get_toplevel (w_current)->page_current->selection_list );
+  object_list = lepton_list_get_glist (active_page->selection_list );
 
   if (object_list) {
     o_mirror_world_update(w_current, wx, wy, object_list);
@@ -795,9 +789,8 @@ i_callback_edit_embed (GtkWidget *widget, gpointer data)
   /* anything selected ? */
   if (o_select_selected(w_current)) {
     /* yes, embed each selected component */
-    LeptonToplevel* toplevel = gschem_toplevel_get_toplevel (w_current);
-    LeptonPage* page      = toplevel->page_current;
-    GList*      s_current = lepton_list_get_glist (page->selection_list);
+    LeptonPage* active_page = schematic_window_get_active_page (w_current);
+    GList* s_current = lepton_list_get_glist (active_page->selection_list);
 
     while (s_current != NULL) {
       o_current = (LeptonObject *) s_current->data;
@@ -840,9 +833,8 @@ i_callback_edit_unembed (GtkWidget *widget, gpointer data)
   /* anything selected ? */
   if (o_select_selected(w_current)) {
     /* yes, unembed each selected component */
-    LeptonToplevel* toplevel = gschem_toplevel_get_toplevel (w_current);
-    LeptonPage* page      = toplevel->page_current;
-    GList*      s_current = lepton_list_get_glist (page->selection_list);
+    LeptonPage* active_page = schematic_window_get_active_page (w_current);
+    GList* s_current = lepton_list_get_glist (active_page->selection_list);
 
     while (s_current != NULL) {
       o_current = (LeptonObject *) s_current->data;
@@ -878,7 +870,6 @@ void
 i_callback_edit_update (GtkWidget *widget, gpointer data)
 {
   GschemToplevel *w_current = GSCHEM_TOPLEVEL (data);
-  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
   GList *selection;
   GList *selected_components = NULL;
   GList *iter;
@@ -891,7 +882,8 @@ i_callback_edit_update (GtkWidget *widget, gpointer data)
      * create a new list of only the LeptonObjects we want to
      * update from the current selection, then iterate over that
      * new list to perform the update. */
-    selection = lepton_list_get_glist (toplevel->page_current->selection_list);
+    LeptonPage *active_page = schematic_window_get_active_page (w_current);
+    selection = lepton_list_get_glist (active_page->selection_list);
     for (iter = selection; iter != NULL; iter = g_list_next (iter)) {
       LeptonObject *o_current = (LeptonObject *) iter->data;
       if (lepton_object_is_component (o_current)) {
@@ -925,8 +917,9 @@ i_callback_edit_show_hidden (GtkWidget *widget, gpointer data)
 
   g_return_if_fail (w_current != NULL);
 
-  o_edit_show_hidden (w_current,
-                      s_page_objects (gschem_toplevel_get_toplevel (w_current)->page_current));
+  LeptonPage *active_page = schematic_window_get_active_page (w_current);
+
+  o_edit_show_hidden (w_current, lepton_page_objects (active_page));
 }
 
 /*! \todo Finish function documentation!!!
@@ -1376,7 +1369,7 @@ i_callback_page_next (GtkWidget *widget, gpointer data)
 {
   GschemToplevel *w_current = GSCHEM_TOPLEVEL (data);
   LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
-  LeptonPage *p_current = toplevel->page_current;
+  LeptonPage *p_current = schematic_window_get_active_page (w_current);
   LeptonPage *p_new;
   GList *iter;
 
@@ -1412,7 +1405,7 @@ i_callback_page_prev (GtkWidget *widget, gpointer data)
 {
   GschemToplevel *w_current = GSCHEM_TOPLEVEL (data);
   LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
-  LeptonPage *p_current = toplevel->page_current;
+  LeptonPage *p_current = schematic_window_get_active_page (w_current);
   LeptonPage *p_new;
   GList *iter;
 
@@ -1448,13 +1441,13 @@ i_callback_page_close (GtkWidget *widget, gpointer data)
   GschemToplevel *w_current = GSCHEM_TOPLEVEL (data);
   g_return_if_fail (w_current != NULL);
 
-  LeptonPage *page = gschem_toplevel_get_toplevel (w_current)->page_current;
+  LeptonPage *page = schematic_window_get_active_page (w_current);
 
   if (page == NULL) {
     return;
   }
 
-  if (page->CHANGED
+  if (lepton_page_get_changed (page)
       && !x_dialog_close_changed_page (w_current, page)) {
     return;
   }
@@ -1504,7 +1497,7 @@ i_callback_page_revert (GtkWidget *widget, gpointer data)
 
   g_return_if_fail (w_current != NULL);
 
-  page_current = gschem_toplevel_get_toplevel (w_current)->page_current;
+  page_current = schematic_window_get_active_page (w_current);
 
   /* do not revert untitled pages:
   */
@@ -1513,7 +1506,7 @@ i_callback_page_revert (GtkWidget *widget, gpointer data)
     return;
   }
 
-  filename = g_strdup (s_page_get_filename (page_current));
+  filename = g_strdup (lepton_page_get_filename (page_current));
 
   const gchar* msg =
     _("<b>Revert page:</b>"
@@ -1612,7 +1605,7 @@ i_callback_page_print (GtkWidget *widget, gpointer data)
 {
   GschemToplevel *w_current = GSCHEM_TOPLEVEL (data);
 
-  s_page_print_all(gschem_toplevel_get_toplevel (w_current));
+  lepton_toplevel_print_all (gschem_toplevel_get_toplevel (w_current));
 }
 
 /*! \section clipboard-menu Clipboard Menu Callback Functions */
@@ -2086,7 +2079,7 @@ i_callback_hierarchy_down_schematic (GtkWidget *widget, gpointer data)
   if (!lepton_object_is_component (object))
     return;
 
-  parent = gschem_toplevel_get_toplevel (w_current)->page_current;
+  parent = schematic_window_get_active_page (w_current);
   attrib = o_attrib_search_attached_attribs_by_name (object, "source", count);
 
   /* if above is null, then look inside symbol */
@@ -2122,12 +2115,12 @@ i_callback_hierarchy_down_schematic (GtkWidget *widget, gpointer data)
       */
       if (child != NULL && !x_tabs_enabled())
       {
-        s_page_goto (gschem_toplevel_get_toplevel (w_current), child);
+        lepton_toplevel_goto_page (gschem_toplevel_get_toplevel (w_current), child);
         gschem_toplevel_page_changed (w_current);
         gschem_page_view_zoom_extents (gschem_toplevel_get_current_page_view (w_current),
                                        NULL);
         o_undo_savestate_old(w_current, UNDO_ALL);
-        s_page_goto (gschem_toplevel_get_toplevel (w_current), parent);
+        lepton_toplevel_goto_page (gschem_toplevel_get_toplevel (w_current), parent);
         gschem_toplevel_page_changed (w_current);
       }
 
@@ -2230,9 +2223,10 @@ i_callback_hierarchy_down_symbol (GtkWidget *widget, gpointer data)
   if (!lepton_object_is_component (object))
     return;
 
-  g_message (_("Searching for symbol [%1$s]"), object->component_basename);
+  gchar *basename = lepton_component_object_get_basename (object);
+  g_message (_("Searching for symbol [%1$s]"), basename);
 
-  const CLibSymbol* sym = s_clib_get_symbol_by_name (object->component_basename);
+  const CLibSymbol* sym = s_clib_get_symbol_by_name (basename);
   if (sym == NULL)
     return;
 
@@ -2246,12 +2240,15 @@ i_callback_hierarchy_down_symbol (GtkWidget *widget, gpointer data)
   g_free (fname);
 
 
-  LeptonToplevel* toplevel = gschem_toplevel_get_toplevel (w_current);
+  LeptonPage *active_page = schematic_window_get_active_page (w_current);
 
-  s_hierarchy_down_symbol (w_current, sym, toplevel->page_current);
+  s_hierarchy_down_symbol (w_current, sym, active_page);
   gschem_toplevel_page_changed (w_current);
 
-  x_window_set_current_page (w_current, toplevel->page_current);
+  /* Get active page once again, it should now be the symbol
+   * page. */
+  active_page = schematic_window_get_active_page (w_current);
+  x_window_set_current_page (w_current, active_page);
 
   /* s_hierarchy_down_symbol() will not zoom the loaded page.
    * Tabbed GUI: zoom is set in x_tabs_page_set_cur().
@@ -2282,17 +2279,18 @@ i_callback_hierarchy_up (GtkWidget *widget, gpointer data)
 
   g_return_if_fail (w_current != NULL);
 
-  page = gschem_toplevel_get_toplevel (w_current)->page_current;
+  page = schematic_window_get_active_page (w_current);
 
   if (page == NULL) {
     return;
   }
 
-  up_page = s_hierarchy_find_up_page (gschem_toplevel_get_toplevel (w_current)->pages, page);
+  up_page = s_hierarchy_find_up_page (page);
   if (up_page == NULL) {
     g_message (_("Cannot find any schematics above the current one!"));
   } else {
-    if (page->CHANGED && !x_dialog_close_changed_page (w_current, page))
+    if (lepton_page_get_changed (page) &&
+        !x_dialog_close_changed_page (w_current, page))
       return;
     x_window_close_page (w_current, page);
     x_window_set_current_page(w_current, up_page);
@@ -2308,7 +2306,6 @@ void
 i_callback_attributes_show_name (GtkWidget *widget, gpointer data)
 {
   GschemToplevel *w_current = GSCHEM_TOPLEVEL (data);
-  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
 
   g_return_if_fail (w_current != NULL);
 
@@ -2318,8 +2315,10 @@ i_callback_attributes_show_name (GtkWidget *widget, gpointer data)
     return;
   }
 
-  if (o_select_selected (w_current)) {
-    LeptonSelection *selection = toplevel->page_current->selection_list;
+  if (o_select_selected (w_current))
+  {
+    LeptonPage *active_page = schematic_window_get_active_page (w_current);
+    LeptonSelection *selection = active_page->selection_list;
     GList *s_current;
 
     for (s_current = lepton_list_get_glist (selection);
@@ -2343,7 +2342,6 @@ void
 i_callback_attributes_show_value (GtkWidget *widget, gpointer data)
 {
   GschemToplevel *w_current = GSCHEM_TOPLEVEL (data);
-  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
 
   g_return_if_fail (w_current != NULL);
 
@@ -2353,8 +2351,10 @@ i_callback_attributes_show_value (GtkWidget *widget, gpointer data)
     return;
   }
 
-  if (o_select_selected (w_current)) {
-    LeptonSelection *selection = toplevel->page_current->selection_list;
+  if (o_select_selected (w_current))
+  {
+    LeptonPage *active_page = schematic_window_get_active_page (w_current);
+    LeptonSelection *selection = active_page->selection_list;
     GList *s_current;
 
     for (s_current = lepton_list_get_glist (selection);
@@ -2378,7 +2378,6 @@ void
 i_callback_attributes_show_both (GtkWidget *widget, gpointer data)
 {
   GschemToplevel *w_current = GSCHEM_TOPLEVEL (data);
-  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
 
   g_return_if_fail (w_current != NULL);
 
@@ -2389,7 +2388,8 @@ i_callback_attributes_show_both (GtkWidget *widget, gpointer data)
   }
 
   if (o_select_selected (w_current)) {
-    LeptonSelection *selection = toplevel->page_current->selection_list;
+    LeptonPage *active_page = schematic_window_get_active_page (w_current);
+    LeptonSelection *selection = active_page->selection_list;
     GList *s_current;
 
     for (s_current = lepton_list_get_glist (selection);
@@ -2413,7 +2413,6 @@ void
 i_callback_attributes_visibility_toggle (GtkWidget *widget, gpointer data)
 {
   GschemToplevel *w_current = GSCHEM_TOPLEVEL (data);
-  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
 
   g_return_if_fail (w_current != NULL);
 
@@ -2423,8 +2422,10 @@ i_callback_attributes_visibility_toggle (GtkWidget *widget, gpointer data)
     return;
   }
 
-  if (o_select_selected (w_current)) {
-    LeptonSelection *selection = toplevel->page_current->selection_list;
+  if (o_select_selected (w_current))
+  {
+    LeptonPage *active_page = schematic_window_get_active_page (w_current);
+    LeptonSelection *selection = active_page->selection_list;
     GList *s_current;
 
     for (s_current = lepton_list_get_glist (selection);
@@ -2505,8 +2506,9 @@ i_callback_options_afeedback (GtkWidget *widget, gpointer data)
     w_current->actionfeedback_mode = BOUNDINGBOX;
     g_message (_("Action feedback mode set to BOUNDINGBOX"));
   }
+  LeptonPage *active_page = schematic_window_get_active_page (w_current);
   if (w_current->inside_action &&
-      gschem_toplevel_get_toplevel (w_current)->page_current->place_list != NULL)
+      active_page->place_list != NULL)
     o_place_invalidate_rubber (w_current, FALSE);
 }
 
@@ -2563,7 +2565,7 @@ i_callback_options_snap (GtkWidget *widget, gpointer data)
     g_message (_("Snap back to the grid (CAUTION!)"));
     break;
   default:
-    g_critical("options_snap: toplevel->snap out of range: %1$d\n",
+    g_critical("options_snap: Invalid snap_mode: %1$d\n",
                snap_mode);
   }
 
@@ -2651,8 +2653,8 @@ void
 i_callback_cancel (GtkWidget *widget, gpointer data)
 {
   GschemToplevel *w_current = GSCHEM_TOPLEVEL (data);
-  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
   GValue value = { 0, };
+  LeptonPage *active_page = schematic_window_get_active_page (w_current);
 
   g_return_if_fail (w_current != NULL);
 
@@ -2688,9 +2690,10 @@ i_callback_cancel (GtkWidget *widget, gpointer data)
   /* Free the place list and its contents. If we were in a move
    * action, the list (refering to objects on the page) would
    * already have been cleared in o_move_cancel(), so this is OK. */
-  if (toplevel->page_current != NULL) {
-    lepton_object_list_delete (toplevel->page_current->place_list);
-    toplevel->page_current->place_list = NULL;
+  if (active_page != NULL)
+  {
+    lepton_object_list_delete (active_page->place_list);
+    active_page->place_list = NULL;
   }
 
   /* leave this on for now... but it might have to change */
