@@ -51,7 +51,6 @@ void o_redraw_rect (GschemToplevel *w_current,
                     GdkRectangle *rectangle)
 #endif
 {
-  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
   gboolean draw_selected;
   int grip_half_size;
   double cue_half_size;
@@ -69,8 +68,6 @@ void o_redraw_rect (GschemToplevel *w_current,
 #endif
 
   g_return_if_fail (w_current != NULL);
-  g_return_if_fail (toplevel != NULL);
-  g_return_if_fail (w_current->toplevel == toplevel);
   g_return_if_fail (page != NULL);
   g_return_if_fail (geometry != NULL);
 #ifndef ENABLE_GTK3
@@ -124,11 +121,10 @@ void o_redraw_rect (GschemToplevel *w_current,
   gboolean show_hidden_text =
     gschem_toplevel_get_show_hidden_text (w_current);
 
-  obj_list = s_page_objects_in_regions (toplevel,
-                                        page,
-                                        world_rect,
-                                        1,
-                                        show_hidden_text);
+  obj_list = lepton_page_objects_in_regions (page,
+                                             world_rect,
+                                             1,
+                                             show_hidden_text);
 
   g_free (world_rect);
 
@@ -366,7 +362,7 @@ int o_invalidate_rubber (GschemToplevel *w_current)
  */
 int o_redraw_cleanstates(GschemToplevel *w_current)
 {
-  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
+  LeptonPage *active_page = schematic_window_get_active_page (w_current);
   /* returns FALSE if the function was'nt nessecary */
   if (w_current->inside_action == 0) {
     return FALSE;
@@ -412,8 +408,8 @@ int o_redraw_cleanstates(GschemToplevel *w_current)
       /* Free the place list and its contents. If we were in a move
        * action, the list (refering to objects on the page) would
        * already have been cleared in o_move_cancel(), so this is OK. */
-      lepton_object_list_delete (toplevel->page_current->place_list);
-      toplevel->page_current->place_list = NULL;
+      lepton_object_list_delete (active_page->place_list);
+      active_page->place_list = NULL;
 
       i_action_stop (w_current);
 
