@@ -86,7 +86,7 @@ void o_bus_end(GschemToplevel *w_current, int w_x, int w_y)
                                      w_current->second_wx,
                                      w_current->second_wy,
                                      0);
-    s_page_append (page, new_obj);
+    lepton_page_append (page, new_obj);
 
     /* connect the new bus to the other busses */
     prev_conn_objects = s_conn_return_others (prev_conn_objects, new_obj);
