@@ -75,7 +75,7 @@ void o_edit(GschemToplevel *w_current, GList *list)
     break;
     case(OBJ_TEXT):
       str = lepton_text_object_get_string (o_current);
-      if (o_attrib_is_attrib (o_current) &&
+      if (lepton_object_is_attrib (o_current) &&
         /* attribute editor only accept 1-line values for attribute */
         o_text_num_lines (str) == 1) {
         attrib_edit_dialog(w_current,o_current, FROM_MENU);
@@ -102,11 +102,11 @@ void o_edit(GschemToplevel *w_current, GList *list)
 void o_lock(GschemToplevel *w_current)
 {
   g_return_if_fail (w_current != NULL);
-  g_return_if_fail (w_current->toplevel != NULL);
-  g_return_if_fail (w_current->toplevel->page_current != NULL);
 
-  LeptonPage*  page = w_current->toplevel->page_current;
-  GList* objs = lepton_list_get_glist (page->selection_list);
+  LeptonPage* active_page = schematic_window_get_active_page (w_current);
+  g_return_if_fail (active_page != NULL);
+
+  GList* objs = lepton_list_get_glist (active_page->selection_list);
 
   /* lock selected objects:
   */
@@ -118,13 +118,14 @@ void o_lock(GschemToplevel *w_current)
 
     /* for objects with attributes, also lock them:
     */
-    if (obj->attribs != NULL)
+    GList *attribs = lepton_object_get_attribs (obj);
+    if (attribs != NULL)
     {
-      lepton_object_list_set_selectable (obj->attribs, FALSE);
+      lepton_object_list_set_selectable (attribs, FALSE);
     }
   }
 
-  gschem_toplevel_page_content_changed (w_current, w_current->toplevel->page_current);
+  schematic_window_active_page_changed (w_current);
 
   if (!w_current->SHIFTKEY)
     o_select_unselect_all(w_current);
@@ -151,11 +152,11 @@ void o_lock(GschemToplevel *w_current)
 void o_unlock(GschemToplevel *w_current)
 {
   g_return_if_fail (w_current != NULL);
-  g_return_if_fail (w_current->toplevel != NULL);
-  g_return_if_fail (w_current->toplevel->page_current != NULL);
 
-  LeptonPage*  page = w_current->toplevel->page_current;
-  GList* objs = lepton_list_get_glist (page->selection_list);
+  LeptonPage* active_page = schematic_window_get_active_page (w_current);
+  g_return_if_fail (active_page != NULL);
+
+  GList* objs = lepton_list_get_glist (active_page->selection_list);
 
   /* unlock selected objects:
   */
@@ -167,13 +168,14 @@ void o_unlock(GschemToplevel *w_current)
 
     /* for objects with attributes, also unlock them:
     */
-    if (obj->attribs != NULL)
+    GList *attribs = lepton_object_get_attribs (obj);
+    if (attribs != NULL)
     {
-      lepton_object_list_set_selectable (obj->attribs, TRUE);
+      lepton_object_list_set_selectable (attribs, TRUE);
     }
   }
 
-  gschem_toplevel_page_content_changed (w_current, page);
+  schematic_window_active_page_changed (w_current);
   o_undo_savestate_old(w_current, UNDO_ALL);
 
   /* refresh view to properly restore attributes' colors:
@@ -201,7 +203,6 @@ void o_unlock(GschemToplevel *w_current)
 void o_rotate_world_update(GschemToplevel *w_current,
                            int centerx, int centery, int angle, GList *list)
 {
-  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
   LeptonObject *o_current;
   GList *o_iter;
 
@@ -243,7 +244,7 @@ void o_rotate_world_update(GschemToplevel *w_current,
 
   /* Don't save the undo state if we are inside an action */
   /* This is useful when rotating the selection while moving, for example */
-  gschem_toplevel_page_content_changed (w_current, toplevel->page_current);
+  schematic_window_active_page_changed (w_current);
   if (!w_current->inside_action) {
     o_undo_savestate_old(w_current, UNDO_ALL);
   }
@@ -260,7 +261,6 @@ void o_rotate_world_update(GschemToplevel *w_current,
  */
 void o_mirror_world_update(GschemToplevel *w_current, int centerx, int centery, GList *list)
 {
-  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
   LeptonObject *o_current;
   GList *o_iter;
 
@@ -299,7 +299,7 @@ void o_mirror_world_update(GschemToplevel *w_current, int centerx, int centery,
   /* Run mirror-objects-hook */
   g_run_hook_object_list (w_current, "%mirror-objects-hook", list);
 
-  gschem_toplevel_page_content_changed (w_current, toplevel->page_current);
+  schematic_window_active_page_changed (w_current);
   o_undo_savestate_old(w_current, UNDO_ALL);
 
   if (w_current->event_state == MIRRORMODE) {
@@ -331,7 +331,8 @@ void o_edit_show_hidden_lowlevel (GschemToplevel *w_current,
 
     if (lepton_object_is_component (o_current))
     {
-      o_edit_show_hidden_lowlevel(w_current, o_current->component->prim_objs);
+      GList *primitives = lepton_component_object_get_contents (o_current);
+      o_edit_show_hidden_lowlevel (w_current, primitives);
     }
 
     iter = g_list_next (iter);
@@ -374,7 +375,6 @@ void o_edit_hide_specific_text (GschemToplevel *w_current,
                                 const GList *o_list,
                                 const char *stext)
 {
-  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
   LeptonObject *o_current;
   const GList *iter;
 
@@ -390,7 +390,7 @@ void o_edit_hide_specific_text (GschemToplevel *w_current,
           lepton_text_object_set_visibility (o_current, INVISIBLE);
           lepton_text_object_recreate (o_current);
 
-          gschem_toplevel_page_content_changed (w_current, toplevel->page_current);
+          schematic_window_active_page_changed (w_current);
         }
       }
     }
@@ -409,7 +409,6 @@ void o_edit_show_specific_text (GschemToplevel *w_current,
                                 const GList *o_list,
                                 const char *stext)
 {
-  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
   LeptonObject *o_current;
   const GList *iter;
 
@@ -425,7 +424,7 @@ void o_edit_show_specific_text (GschemToplevel *w_current,
           lepton_text_object_set_visibility (o_current, VISIBLE);
           lepton_text_object_recreate (o_current);
 
-          gschem_toplevel_page_content_changed (w_current, toplevel->page_current);
+          schematic_window_active_page_changed (w_current);
         }
       }
     }
@@ -441,7 +440,7 @@ void o_edit_show_specific_text (GschemToplevel *w_current,
  * Updates \a o_current to the latest version of the symbol available
  * in the symbol library, while preserving any attributes set in the
  * current schematic. On success, returns the new LeptonObject which
- * replaces \a o_current on the page; \a o_current is deleted. On
+ * replaces \a o_current on its page; \a o_current is deleted. On
  * failure, returns NULL, and \a o_current is left unchanged.
  *
  * \param [in]     w_current The GschemToplevel object.
@@ -452,7 +451,6 @@ void o_edit_show_specific_text (GschemToplevel *w_current,
 LeptonObject *
 o_update_component (GschemToplevel *w_current, LeptonObject *o_current)
 {
-  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
   LeptonObject *o_new;
   LeptonPage *page;
   GList *new_attribs;
@@ -461,17 +459,19 @@ o_update_component (GschemToplevel *w_current, LeptonObject *o_current)
   const CLibSymbol *clib;
 
   g_return_val_if_fail (lepton_object_is_component (o_current), NULL);
-  g_return_val_if_fail (o_current->component_basename != NULL, NULL);
+
+  gchar *basename = lepton_component_object_get_basename (o_current);
+  g_return_val_if_fail (basename != NULL, NULL);
 
   page = lepton_object_get_page (o_current);
 
   /* Force symbol data to be reloaded from source */
-  clib = s_clib_get_symbol_by_name (o_current->component_basename);
+  clib = s_clib_get_symbol_by_name (basename);
   s_clib_symbol_invalidate_data (clib);
 
   if (clib == NULL) {
     g_message (_("Could not find symbol [%1$s] in library. Update failed."),
-                   o_current->component_basename);
+               basename);
     return NULL;
   }
 
@@ -479,22 +479,21 @@ o_update_component (GschemToplevel *w_current, LeptonObject *o_current)
   o_selection_remove (page->selection_list, o_current);
 
   /* Create new object and set embedded */
-  o_new = o_component_new (toplevel->page_current,
-                           OBJ_COMPONENT,
-                           default_color_id(),
-                           o_current->component->x,
-                           o_current->component->y,
-                           o_current->component->angle,
-                           o_current->component->mirror,
-                           clib,
-                           o_current->component_basename,
-                           1);
+  o_new = lepton_component_new (page,
+                                default_color_id(),
+                                lepton_component_object_get_x (o_current),
+                                lepton_component_object_get_y (o_current),
+                                lepton_component_object_get_angle (o_current),
+                                lepton_component_object_get_mirror (o_current),
+                                clib,
+                                basename,
+                                1);
   /* Embed new object if the old one is embedded. */
   if (lepton_component_object_get_embedded (o_current)) {
     lepton_component_object_embed (o_new);
   }
 
-  new_attribs = o_component_promote_attribs (o_new);
+  new_attribs = lepton_component_promote_attribs (o_new);
 
   /* Cull any attributes from new COMPONENT that are already attached to
    * old COMPONENT. Note that the new_attribs list is kept consistent by
@@ -509,11 +508,11 @@ o_update_component (GschemToplevel *w_current, LeptonObject *o_current)
 
     g_assert (lepton_object_is_text (attr_new));
 
-    o_attrib_get_name_value (attr_new, &name, NULL);
+    name = g_strdup (lepton_text_object_get_name (attr_new));
 
     value = o_attrib_search_attached_attribs_by_name (o_current, name, 0);
+
     if (value != NULL) {
-      o_attrib_remove (&o_new->attribs, attr_new);
       lepton_object_delete (attr_new);
       iter->data = NULL;
     }
@@ -524,26 +523,26 @@ o_update_component (GschemToplevel *w_current, LeptonObject *o_current)
   new_attribs = g_list_remove_all (new_attribs, NULL);
 
   /* Detach attributes from old LeptonObject and attach to new LeptonObject */
-  old_attribs = g_list_copy (o_current->attribs);
+  old_attribs = g_list_copy (lepton_object_get_attribs (o_current));
   o_attrib_detach_all (o_current);
   o_attrib_attach_list (old_attribs, o_new, 1);
   g_list_free (old_attribs);
 
   /* Add new attributes to page */
-  s_page_append_list (page, new_attribs);
+  lepton_page_append_list (page, new_attribs);
 
   /* Update pinnumbers for current slot */
   s_slot_update_object (o_new);
 
   /* Replace old LeptonObject with new LeptonObject */
-  s_page_replace (page, o_current, o_new);
+  lepton_page_replace (page, o_current, o_new);
   lepton_object_delete (o_current);
 
   /* Select new LeptonObject */
   o_selection_add (page->selection_list, o_new);
 
   /* mark the page as modified */
-  gschem_toplevel_page_content_changed (w_current, toplevel->page_current);
+  gschem_toplevel_page_content_changed (w_current, page);
   o_undo_savestate_old (w_current, UNDO_ALL);
 
   return o_new;
@@ -570,7 +569,7 @@ void o_autosave_backups(GschemToplevel *w_current)
   struct stat st;
 
   /* save current page */
-  p_save = toplevel->page_current;
+  p_save = schematic_window_get_active_page (w_current);
 
   for ( iter = lepton_list_get_glist( toplevel->pages );
         iter != NULL;
@@ -583,16 +582,16 @@ void o_autosave_backups(GschemToplevel *w_current)
     }
     if (p_current->ops_since_last_backup != 0) {
       /* make p_current the current page of toplevel */
-      s_page_goto (toplevel, p_current);
+      lepton_toplevel_goto_page (toplevel, p_current);
       gschem_toplevel_page_changed (w_current);
 
       /* Get the real filename and file permissions */
-      real_filename = follow_symlinks (s_page_get_filename (p_current), NULL);
+      real_filename = follow_symlinks (lepton_page_get_filename (p_current), NULL);
 
       if (real_filename == NULL) {
         g_message ("o_autosave_backups: ");
         g_message (_("Can't get the real filename of %1$s."),
-                   s_page_get_filename (p_current));
+                   lepton_page_get_filename (p_current));
       } else {
         /* Get the directory in which the real filename lives */
         dirname = g_path_get_dirname (real_filename);
@@ -642,11 +641,11 @@ void o_autosave_backups(GschemToplevel *w_current)
           umask(saved_umask);
         }
 
-        if (o_save (s_page_objects (toplevel->page_current),
+        if (o_save (lepton_page_objects (schematic_window_get_active_page (w_current)),
                     backup_filename, NULL)) {
 
           p_current->ops_since_last_backup = 0;
-                p_current->do_autosave_backup = 0;
+          p_current->do_autosave_backup = 0;
 
           /* Make the backup file readonly so a 'rm *' command will ask
              the user before deleting it */
@@ -668,6 +667,6 @@ void o_autosave_backups(GschemToplevel *w_current)
     }
   }
   /* restore current page */
-  s_page_goto (toplevel, p_save);
+  lepton_toplevel_goto_page (toplevel, p_save);
   gschem_toplevel_page_changed (w_current);
 }
