@@ -382,7 +382,6 @@ void o_select_box_draw_rubber (GschemToplevel *w_current, EdaRenderer *renderer)
  */
 void o_select_box_search(GschemToplevel *w_current)
 {
-  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
   LeptonObject *o_current=NULL;
   int count = 0; /* object count */
   int SHIFTKEY = w_current->SHIFTKEY;
@@ -397,7 +396,9 @@ void o_select_box_search(GschemToplevel *w_current)
   top = MIN(w_current->first_wy, w_current->second_wy);
   bottom = MAX(w_current->first_wy, w_current->second_wy);
 
-  iter = s_page_objects (toplevel->page_current);
+  LeptonPage *active_page = schematic_window_get_active_page (w_current);
+
+  iter = lepton_page_objects (active_page);
   while (iter != NULL) {
     o_current = (LeptonObject*) iter->data;
     /* only select visible objects */
@@ -445,7 +446,6 @@ void o_select_box_search(GschemToplevel *w_current)
  */
 void o_select_connected_nets(GschemToplevel *w_current, LeptonObject* o_net)
 {
-  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
   const GList *o_iter;
   GList *iter1;
   LeptonObject *o_current;
@@ -508,18 +508,24 @@ void o_select_connected_nets(GschemToplevel *w_current, LeptonObject* o_net)
     if (netnameiter == g_list_last(netnamestack))
       break; /* no new netnames in the stack --> finished */
 
+    LeptonPage *active_page = schematic_window_get_active_page (w_current);
+
     /* get all the nets of the stacked netnames */
-    for (o_iter = s_page_objects (toplevel->page_current);
+    for (o_iter = lepton_page_objects (active_page);
          o_iter != NULL;
          o_iter = g_list_next (o_iter)) {
       o_current = (LeptonObject*) o_iter->data;
+      LeptonObject *attachment = lepton_object_get_attached_to (o_current);
+
       if (lepton_object_is_text (o_current)
-          && o_current->attached_to != NULL) {
-        if (lepton_object_is_net (o_current->attached_to)) {
-          netname = o_attrib_search_object_attribs_by_name (o_current->attached_to, "netname", 0);
+          && attachment != NULL)
+      {
+        if (lepton_object_is_net (attachment))
+        {
+          netname = o_attrib_search_object_attribs_by_name (attachment, "netname", 0);
           if (netname != NULL) {
             if (g_list_find_custom(netnamestack, netname, (GCompareFunc) strcmp) != NULL) {
-              netstack = g_list_prepend(netstack, o_current->attached_to);
+              netstack = g_list_prepend (netstack, attachment);
             }
             g_free(netname);
           }
@@ -601,15 +607,16 @@ void o_select_unselect_all(GschemToplevel *w_current)
 void
 o_select_visible_unlocked (GschemToplevel *w_current)
 {
-  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
-  LeptonSelection *selection = toplevel->page_current->selection_list;
   const GList *iter;
   GList *added;
   gboolean show_hidden_text =
     gschem_toplevel_get_show_hidden_text (w_current);
 
+  LeptonPage *active_page = schematic_window_get_active_page (w_current);
+  LeptonSelection *selection = active_page->selection_list;
+
   o_select_unselect_all (w_current);
-  for (iter = s_page_objects (toplevel->page_current);
+  for (iter = lepton_page_objects (active_page);
        iter != NULL;
        iter = g_list_next (iter)) {
     LeptonObject *obj = (LeptonObject *) iter->data;
@@ -621,7 +628,7 @@ o_select_visible_unlocked (GschemToplevel *w_current)
       continue;
 
     /* Skip locked objects. */
-    if (!obj->selectable) continue;
+    if (!lepton_object_get_selectable(obj)) continue;
 
     /* Add object to selection. */
     /*! \bug We can't call o_select_object() because it
@@ -650,15 +657,16 @@ o_select_visible_unlocked (GschemToplevel *w_current)
 void
 o_select_move_to_place_list(GschemToplevel *w_current)
 {
-  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
   GList *selection;
   GList *selection_copy;
 
-  /* remove the old place list if it exists */
-  lepton_object_list_delete (toplevel->page_current->place_list);
-  toplevel->page_current->place_list = NULL;
+  LeptonPage *active_page = schematic_window_get_active_page (w_current);
 
-  selection = lepton_list_get_glist( toplevel->page_current->selection_list );
+  /* remove the old place list if it exists */
+  lepton_object_list_delete (active_page->place_list);
+  active_page->place_list = NULL;
+
+  selection = lepton_list_get_glist( active_page->selection_list );
   selection_copy = g_list_copy( selection );
-  toplevel->page_current->place_list = selection_copy;
+  active_page->place_list = selection_copy;
 }
