@@ -167,7 +167,9 @@ page_select_widget_update (GschemToplevel* w_current)
     return;
   }
 
-  i_set_filename (w_current, s_page_get_filename (page), page->CHANGED);
+  i_set_filename (w_current,
+                  lepton_page_get_filename (page),
+                  lepton_page_get_changed (page));
 
   if (x_tabs_enabled())
   {
@@ -203,7 +205,7 @@ pagesel_callback_selection_changed (GtkTreeSelection* selection,
   /* Since setting the current page may call page_select_widget_update(), which
    * might change the current page selection, make sure we do nothing
    * if the newly-selected page is already the current page. */
-  if (page == w_current->toplevel->page_current)
+  if (page == schematic_window_get_active_page (w_current))
   {
     return;
   }
@@ -630,7 +632,7 @@ add_page (GtkTreeModel *model,
                          &iter,
                          parent);
 
-  const gchar* page_filename = s_page_get_filename (page);
+  const gchar* page_filename = lepton_page_get_filename (page);
   gchar* display_filename = pagesel->show_paths_
                             ? g_strdup (page_filename)
                             : g_path_get_basename (page_filename);
@@ -639,7 +641,7 @@ add_page (GtkTreeModel *model,
                       &iter,
                       COLUMN_PAGE, page,
                       COLUMN_NAME, display_filename,
-                      COLUMN_CHANGED, page->CHANGED,
+                      COLUMN_CHANGED, lepton_page_get_changed (page),
                       -1);
 
   g_free (display_filename);
@@ -716,9 +718,11 @@ pagesel_update (PageSelectWidget* pagesel)
   GList *iter;
 
   g_assert (IS_PAGE_SELECT_WIDGET (pagesel));
-  g_return_if_fail (pagesel->toplevel_ != NULL);
 
-  toplevel = gschem_toplevel_get_toplevel (pagesel->toplevel_);
+  GschemToplevel *w_current = pagesel->toplevel_;
+  g_return_if_fail (w_current != NULL);
+
+  toplevel = gschem_toplevel_get_toplevel (w_current);
   model    = gtk_tree_view_get_model (pagesel->treeview_);
 
   /* wipe out every thing in the store */
@@ -740,13 +744,15 @@ pagesel_update (PageSelectWidget* pagesel)
     p_current = (LeptonPage *)iter->data;
     /* find every page that is not a hierarchy-down of another page */
     if (p_current->up < 0 ||
-        s_page_search_by_page_id (toplevel->pages,
-                                  p_current->up) == NULL) {
+        lepton_toplevel_search_page_by_id (toplevel->pages,
+                                           p_current->up) == NULL) {
       add_page (model, NULL, toplevel->pages, p_current, pagesel);
     }
   }
 
   /* select the current page in the treeview */
-  select_page (pagesel->treeview_, NULL, toplevel->page_current);
+  select_page (pagesel->treeview_,
+               NULL,
+               schematic_window_get_active_page (w_current));
 
 } /* pagesel_update() */
