@@ -393,13 +393,15 @@ void autonumber_get_used(GschemToplevel *w_current, AUTONUMBER_TEXT *autotext)
   char *numslot_str, *slot_str;
   const GList *iter;
 
-  for (iter = s_page_objects (w_current->toplevel->page_current);
+  LeptonPage *active_page = schematic_window_get_active_page (w_current);
+
+  for (iter = lepton_page_objects (active_page);
        iter != NULL;
        iter = g_list_next (iter)) {
     o_current = (LeptonObject*) iter->data;
     if (autonumber_match(autotext, o_current, &number) == AUTONUMBER_RESPECT) {
       /* check slot and maybe add it to the lists */
-      o_parent = o_current->attached_to;
+      o_parent = lepton_object_get_attached_to (o_current);
       if (autotext->slotting && o_parent != NULL) {
         /* check for slotted symbol */
         numslot_str =
@@ -419,7 +421,7 @@ void autonumber_get_used(GschemToplevel *w_current, AUTONUMBER_TEXT *autotext)
               slot = g_new(AUTONUMBER_SLOT,1);
               slot->number = number;
               slot->slotnr = slotnr;
-              slot->symbolname = o_parent->component_basename;
+              slot->symbolname = lepton_component_object_get_basename (o_parent);
 
 
               slot_item = g_list_find_custom(autotext->used_slots,
@@ -492,10 +494,10 @@ void autonumber_get_new_numbers(AUTONUMBER_TEXT *autotext, LeptonObject *o_curre
 
   /* Check for slots first */
   /* 1. are there any unused slots in the database? */
-  o_parent = o_current->attached_to;
+  o_parent = lepton_object_get_attached_to (o_current);
   if (autotext->slotting && o_parent != NULL) {
     freeslot = g_new(AUTONUMBER_SLOT,1);
-    freeslot->symbolname = o_parent->component_basename;
+    freeslot->symbolname = lepton_component_object_get_basename (o_parent);
     freeslot->number = 0;
     freeslot->slotnr = 0;
     freeslot_item = g_list_find_custom(autotext->free_slots,
@@ -545,7 +547,7 @@ void autonumber_get_new_numbers(AUTONUMBER_TEXT *autotext, LeptonObject *o_curre
         *slot = 1;
         for (i=2; i <=numslots; i++) {
           freeslot = g_new(AUTONUMBER_SLOT,1);
-          freeslot->symbolname = o_parent->component_basename;
+          freeslot->symbolname = lepton_component_object_get_basename (o_parent);
           freeslot->number = new_number;
           freeslot->slotnr = i;
           autotext->free_slots = g_list_insert_sorted(autotext->free_slots,
@@ -579,7 +581,7 @@ void autonumber_remove_number(AUTONUMBER_TEXT * autotext, LeptonObject *o_curren
   /* remove the slot attribute if slotting is active */
   if (autotext->slotting) {
     /* get the slot attribute */
-    o_parent = o_current->attached_to;
+    o_parent = lepton_object_get_attached_to (o_current);
     if (o_parent != NULL) {
       slot_str = s_slot_search_slot (o_parent, &o_slot);
       g_free (slot_str);
@@ -591,8 +593,7 @@ void autonumber_remove_number(AUTONUMBER_TEXT * autotext, LeptonObject *o_curren
     }
   }
 
-  gschem_toplevel_page_content_changed (autotext->w_current,
-                                        autotext->w_current->toplevel->page_current);
+  schematic_window_active_page_changed (autotext->w_current);
 }
 
 /*! \brief Changes the number <B>LeptonObject</B> element. Changes the slot attribute.
@@ -609,7 +610,9 @@ void autonumber_apply_new_text(AUTONUMBER_TEXT * autotext, LeptonObject *o_curre
   if (slot != 0) {
     /* update the slot on the owning object */
     str = g_strdup_printf ("slot=%d", slot);
-    o_slot_end (autotext->w_current, o_current->attached_to, str);
+    o_slot_end (autotext->w_current,
+                lepton_object_get_attached_to (o_current),
+                str);
     g_free (str);
   }
 
@@ -618,8 +621,7 @@ void autonumber_apply_new_text(AUTONUMBER_TEXT * autotext, LeptonObject *o_curre
   lepton_text_object_set_string (o_current, str);
   g_free (str);
 
-  gschem_toplevel_page_content_changed (autotext->w_current,
-                                        autotext->w_current->toplevel->page_current);
+  schematic_window_active_page_changed (autotext->w_current);
 }
 
 
@@ -646,8 +648,10 @@ void autonumber_text_autonumber(AUTONUMBER_TEXT *autotext)
   size_t i;
   GList *o_list = NULL;
   const GList *iter;
+  LeptonPage *active_page = NULL;
 
   w_current = autotext->w_current;
+  active_page = schematic_window_get_active_page (w_current);
   autotext->current_searchtext = NULL;
   autotext->root_page = 1;
   autotext->used_numbers = NULL;
@@ -658,7 +662,7 @@ void autonumber_text_autonumber(AUTONUMBER_TEXT *autotext)
 
   /* Step1: get all pages of the hierarchy */
   pages = s_hierarchy_traversepages (w_current,
-                                     w_current->toplevel->page_current,
+                                     active_page,
                                      HIERARCHY_NODUPS);
 
   /*  g_list_foreach(pages, (GFunc) s_hierarchy_print_page, NULL); */
@@ -687,10 +691,10 @@ void autonumber_text_autonumber(AUTONUMBER_TEXT *autotext)
     searchtext = g_strndup(scope_text, strlen(scope_text)-1);
     /* collect all the possible searchtexts in all pages of the hierarchy */
     for (page_item = pages; page_item != NULL; page_item = g_list_next(page_item)) {
-      s_page_goto (w_current->toplevel, (LeptonPage*) page_item->data);
+      lepton_toplevel_goto_page (w_current->toplevel, (LeptonPage*) page_item->data);
       gschem_toplevel_page_changed (w_current);
       /* iterate over all objects an look for matching searchtext's */
-      for (iter = s_page_objects (w_current->toplevel->page_current);
+      for (iter = lepton_page_objects (active_page);
            iter != NULL;
            iter = g_list_next (iter)) {
         o_current = (LeptonObject*) iter->data;
@@ -743,7 +747,8 @@ void autonumber_text_autonumber(AUTONUMBER_TEXT *autotext)
             && autotext->scope_overwrite)) {
         for (page_item = pages; page_item != NULL; page_item = g_list_next(page_item)) {
           autotext->root_page = (pages->data == page_item->data);
-          s_page_goto(w_current->toplevel, (LeptonPage*) page_item->data);
+          lepton_toplevel_goto_page (w_current->toplevel,
+                                     (LeptonPage*) page_item->data);
           gschem_toplevel_page_changed (w_current);
           autonumber_get_used(w_current, autotext);
         }
@@ -752,7 +757,8 @@ void autonumber_text_autonumber(AUTONUMBER_TEXT *autotext)
 
     /* renumber the elements */
     for (page_item = pages; page_item != NULL; page_item = g_list_next(page_item)) {
-      s_page_goto(w_current->toplevel, (LeptonPage*) page_item->data);
+      lepton_toplevel_goto_page (w_current->toplevel,
+                                 (LeptonPage*) page_item->data);
       gschem_toplevel_page_changed (w_current);
       autotext->root_page = (pages->data == page_item->data);
       /* build a page database if we're numbering pagebypage or selection only*/
@@ -762,7 +768,7 @@ void autonumber_text_autonumber(AUTONUMBER_TEXT *autotext)
 
       /* RENUMBER CODE FOR ONE PAGE AND ONE SEARCHTEXT*/
       /* 1. get objects to renumber */
-      for (iter = s_page_objects (w_current->toplevel->page_current);
+      for (iter = lepton_page_objects (active_page);
            iter != NULL;
            iter = g_list_next (iter)) {
         o_current = (LeptonObject*) iter->data;
@@ -823,7 +829,8 @@ void autonumber_text_autonumber(AUTONUMBER_TEXT *autotext)
   /* cleanup and redraw all*/
   g_list_foreach(searchtext_list, (GFunc) g_free, NULL);
   g_list_free(searchtext_list);
-  s_page_goto(w_current->toplevel, (LeptonPage*) pages->data); /* go back to the root page */
+  lepton_toplevel_goto_page (w_current->toplevel,
+                             (LeptonPage*) pages->data); /* go back to the root page */
   gschem_toplevel_page_changed (w_current);
   gschem_page_view_invalidate_all (gschem_toplevel_get_current_page_view (w_current));
   g_list_free(pages);
@@ -1195,7 +1202,6 @@ GtkWidget* autonumber_create_dialog(GschemToplevel *w_current)
   GtkWidget *vbox1;
   GtkWidget *alignment1;
   GtkWidget *vbox3;
-  GtkWidget *table1;
   GtkWidget *label4;
   GtkWidget *scope_text;
   GtkWidget *label8;
@@ -1206,7 +1212,6 @@ GtkWidget* autonumber_create_dialog(GschemToplevel *w_current)
   GtkWidget *label1;
   GtkWidget *alignment3;
   GtkWidget *vbox4;
-  GtkWidget *table3;
   GtkWidget *label12;
   GtkWidget *label13;
   GtkWidget *opt_startnum;
@@ -1259,54 +1264,86 @@ GtkWidget* autonumber_create_dialog(GschemToplevel *w_current)
   gtk_widget_show (vbox3);
   gtk_container_add (GTK_CONTAINER (alignment1), vbox3);
 
-  table1 = gtk_table_new (3, 2, FALSE);
+#ifdef ENABLE_GTK3
+  GtkWidget* grid1 = gtk_grid_new ();
+  gtk_widget_show (grid1);
+  gtk_box_pack_start (GTK_BOX (vbox3), grid1, TRUE, TRUE, 0);
+  gtk_grid_set_row_spacing (GTK_GRID (grid1), DIALOG_V_SPACING);
+  gtk_grid_set_column_spacing (GTK_GRID (grid1), DIALOG_H_SPACING);
+#else
+  GtkWidget *table1 = gtk_table_new (3, 2, FALSE);
   gtk_widget_show (table1);
   gtk_box_pack_start (GTK_BOX (vbox3), table1, TRUE, TRUE, 0);
   gtk_table_set_row_spacings (GTK_TABLE (table1), DIALOG_V_SPACING);
   gtk_table_set_col_spacings (GTK_TABLE (table1), DIALOG_H_SPACING);
+#endif
 
   label4 = gtk_label_new (_("Search for:"));
   gtk_widget_show (label4);
+#ifdef ENABLE_GTK3
+  gtk_grid_attach (GTK_GRID (grid1), label4, 0, 0, 1, 1);
+#else
   gtk_table_attach (GTK_TABLE (table1), label4, 0, 1, 0, 1,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
+#endif
   gtk_misc_set_alignment (GTK_MISC (label4), 0, 0.5);
 
   scope_text = gtk_combo_box_text_new_with_entry ();
   gtk_entry_set_activates_default(GTK_ENTRY(gtk_bin_get_child(GTK_BIN(scope_text))), TRUE);
   gtk_widget_show (scope_text);
+#ifdef ENABLE_GTK3
+  gtk_grid_attach (GTK_GRID (grid1), scope_text, 1, 0, 1, 1);
+#else
   gtk_table_attach (GTK_TABLE (table1), scope_text, 1, 2, 0, 1,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (GTK_FILL), 0, 0);
+#endif
 
   label8 = gtk_label_new (_("Autonumber text in:"));
   gtk_widget_show (label8);
+#ifdef ENABLE_GTK3
+  gtk_grid_attach (GTK_GRID (grid1), label8, 0, 1, 1, 1);
+#else
   gtk_table_attach (GTK_TABLE (table1), label8, 0, 1, 1, 2,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
+#endif
   gtk_misc_set_alignment (GTK_MISC (label8), 0, 0.5);
 
   label6 = gtk_label_new (_("Skip numbers found in:"));
   gtk_widget_show (label6);
+#ifdef ENABLE_GTK3
+  gtk_grid_attach (GTK_GRID (grid1), label6, 0, 2, 1, 1);
+#else
   gtk_table_attach (GTK_TABLE (table1), label6, 0, 1, 2, 3,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
+#endif
   gtk_misc_set_alignment (GTK_MISC (label6), 0, 0.5);
 
   scope_number = gtk_combo_box_text_new ();
   gtk_widget_show (scope_number);
+#ifdef ENABLE_GTK3
+  gtk_grid_attach (GTK_GRID (grid1), scope_number, 1, 1, 1, 1);
+#else
   gtk_table_attach (GTK_TABLE (table1), scope_number, 1, 2, 1, 2,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (GTK_FILL), 0, 0);
+#endif
   gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (scope_number), _("Selected objects"));
   gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (scope_number), _("Current page"));
   gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (scope_number), _("Whole hierarchy"));
 
   scope_skip = gtk_combo_box_text_new ();
   gtk_widget_show (scope_skip);
+#ifdef ENABLE_GTK3
+  gtk_grid_attach (GTK_GRID (grid1), scope_skip, 1, 2, 1, 1);
+#else
   gtk_table_attach (GTK_TABLE (table1), scope_skip, 1, 2, 2, 3,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (GTK_FILL), 0, 0);
+#endif
   gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (scope_skip), _("Selected objects"));
   gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (scope_skip), _("Current page"));
   gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (scope_skip), _("Whole hierarchy"));
@@ -1336,24 +1373,40 @@ GtkWidget* autonumber_create_dialog(GschemToplevel *w_current)
   gtk_widget_show (vbox4);
   gtk_container_add (GTK_CONTAINER (alignment3), vbox4);
 
-  table3 = gtk_table_new (2, 2, FALSE);
+#ifdef ENABLE_GTK3
+  GtkWidget *grid3 = gtk_grid_new ();
+  gtk_widget_show (grid3);
+  gtk_box_pack_start (GTK_BOX (vbox4), grid3, TRUE, TRUE, 0);
+  gtk_grid_set_row_spacing (GTK_GRID (grid3), DIALOG_V_SPACING);
+  gtk_grid_set_column_spacing (GTK_GRID (grid3), DIALOG_H_SPACING);
+#else
+  GtkWidget *table3 = gtk_table_new (2, 2, FALSE);
   gtk_widget_show (table3);
   gtk_box_pack_start (GTK_BOX (vbox4), table3, TRUE, TRUE, 0);
   gtk_table_set_row_spacings (GTK_TABLE (table3), DIALOG_V_SPACING);
   gtk_table_set_col_spacings (GTK_TABLE (table3), DIALOG_H_SPACING);
+#endif
 
   label12 = gtk_label_new (_("Starting number:"));
   gtk_widget_show (label12);
+#ifdef ENABLE_GTK3
+  gtk_grid_attach (GTK_GRID (grid3), label12, 0, 0, 1, 1);
+#else
   gtk_table_attach (GTK_TABLE (table3), label12, 0, 1, 0, 1,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
+#endif
   gtk_misc_set_alignment (GTK_MISC (label12), 0, 0.5);
 
   label13 = gtk_label_new (_("Sort order:"));
   gtk_widget_show (label13);
+#ifdef ENABLE_GTK3
+  gtk_grid_attach (GTK_GRID (grid3), label13, 0, 1, 1, 1);
+#else
   gtk_table_attach (GTK_TABLE (table3), label13, 0, 1, 1, 2,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
+#endif
   gtk_misc_set_alignment (GTK_MISC (label13), 0, 0.5);
 
 
@@ -1371,15 +1424,23 @@ GtkWidget* autonumber_create_dialog(GschemToplevel *w_current)
 
   gtk_entry_set_activates_default(GTK_ENTRY(opt_startnum), TRUE);
   gtk_widget_show (opt_startnum);
+#ifdef ENABLE_GTK3
+  gtk_grid_attach (GTK_GRID (grid3), opt_startnum, 1, 0, 1, 1);
+#else
   gtk_table_attach (GTK_TABLE (table3), opt_startnum, 1, 2, 0, 1,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
+#endif
 
   sort_order = gtk_combo_box_new();
   gtk_widget_show (sort_order);
+#ifdef ENABLE_GTK3
+  gtk_grid_attach (GTK_GRID (grid3), sort_order, 1, 1, 1, 1);
+#else
   gtk_table_attach (GTK_TABLE (table3), sort_order, 1, 2, 1, 2,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (GTK_FILL), 0, 0);
+#endif
 
   opt_removenum = gtk_check_button_new_with_mnemonic (_("Remove numbers"));
   gtk_widget_show (opt_removenum);
