@@ -437,9 +437,9 @@ enum {
  *  \param [in] compselect       The dialog compselect
  *  \param [in] preview_toplevel The toplevel of the preview widget
  */
-void
+static void
 update_attributes_model (Compselect *compselect,
-                         LeptonToplevel *preview_toplevel)
+                         GschemToplevel *preview_toplevel)
 {
   GtkListStore *model;
   GtkTreeIter iter;
@@ -469,14 +469,15 @@ update_attributes_model (Compselect *compselect,
                                      ATTRIBUTE_COLUMN_VALUE);
   gtk_tree_view_column_queue_resize (column);
 
-  if (preview_toplevel->page_current == NULL) {
+  LeptonPage *active_page = schematic_window_get_active_page (preview_toplevel);
+
+  if (active_page == NULL) {
     return;
   }
 
-  o_attrlist = o_attrib_find_floating_attribs (
-                              s_page_objects (preview_toplevel->page_current));
+  o_attrlist = o_attrib_find_floating_attribs (lepton_page_objects (active_page));
 
-  cfg = eda_config_get_context_for_path (s_page_get_filename (preview_toplevel->page_current));
+  cfg = eda_config_get_context_for_path (lepton_page_get_filename (active_page));
   filter_list = eda_config_get_string_list (cfg, "schematic.library",
                                             "component-attributes", &n, NULL);
 
@@ -485,7 +486,8 @@ update_attributes_model (Compselect *compselect,
     o_attrlist = g_list_sort (o_attrlist, (GCompareFunc) sort_object_text);
     for (o_iter = o_attrlist; o_iter != NULL; o_iter = g_list_next (o_iter)) {
       o_current = (LeptonObject*) o_iter->data;
-      o_attrib_get_name_value (o_current, &name, &value);
+      name = g_strdup (lepton_text_object_get_name (o_current));
+      value = g_strdup (lepton_text_object_get_value (o_current));
       gtk_list_store_append (model, &iter);
       gtk_list_store_set (model, &iter, 0, name, 1, value, -1);
       g_free (name);
@@ -496,7 +498,10 @@ update_attributes_model (Compselect *compselect,
     for (i = 0; i < n; i++) {
       for (o_iter = o_attrlist; o_iter != NULL; o_iter = g_list_next (o_iter)) {
         o_current = (LeptonObject*) o_iter->data;
-        if (o_attrib_get_name_value (o_current, &name, &value)) {
+        name = g_strdup (lepton_text_object_get_name (o_current));
+        if (name)
+        {
+          value = g_strdup (lepton_text_object_get_value (o_current));
           if (strcmp (name, filter_list[i]) == 0) {
             gtk_list_store_append (model, &iter);
             gtk_list_store_set (model, &iter, 0, name, 1, value, -1);
@@ -563,7 +568,7 @@ compselect_callback_tree_selection_changed (GtkTreeSelection *selection,
 
   /* update the attributes with the toplevel of the preview widget*/
   update_attributes_model (compselect,
-                           compselect->preview->preview_w_current->toplevel);
+                           compselect->preview->preview_w_current);
 
   /* signal a component has been selected to parent of dialog */
   g_signal_emit_by_name (compselect,
@@ -851,8 +856,8 @@ create_lib_tree_model (Compselect *compselect)
 {
   GtkTreeStore *store;
   GList *srchead, *srclist;
-  LeptonPage *page = GSCHEM_DIALOG(compselect)->w_current->toplevel->page_current;
-  EdaConfig *cfg = eda_config_get_context_for_path (s_page_get_filename (page));
+  LeptonPage *active_page = schematic_window_get_active_page (GSCHEM_DIALOG(compselect)->w_current);
+  EdaConfig *cfg = eda_config_get_context_for_path (lepton_page_get_filename (active_page));
   gboolean sort = eda_config_get_boolean (cfg, "schematic.library", "sort", NULL);
 
   store = (GtkTreeStore*)gtk_tree_store_new (3, G_TYPE_POINTER,
@@ -1478,15 +1483,24 @@ compselect_constructor (GType type,
                 "default-width",   400,
                 NULL);
 
-  /* vertical pane containing preview and attributes */
-  vpaned = GTK_WIDGET (g_object_new (GTK_TYPE_VPANED, NULL));
-  compselect->vpaned = vpaned;
+  /* vpaned is vertical pane containing preview and attributes.
+   * hpaned is horizontal pane containing selection and
+   * preview. */
 
-  /* horizontal pane containing selection and preview */
+#ifdef ENABLE_GTK3
+  vpaned = gtk_paned_new (GTK_ORIENTATION_VERTICAL);
+  hpaned = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
+#else
+  vpaned = GTK_WIDGET (g_object_new (GTK_TYPE_VPANED, NULL));
   hpaned = GTK_WIDGET (g_object_new (GTK_TYPE_HPANED,
                                     /* GtkContainer */
                                     "border-width", 5,
                                      NULL));
+#endif
+
+  gtk_container_set_border_width (GTK_CONTAINER (hpaned), 5);
+
+  compselect->vpaned = vpaned;
   compselect->hpaned = hpaned;
 
   /* notebook for library and inuse views */
