@@ -771,6 +771,39 @@ gint x_event_scroll (GtkWidget *widget, GdkEventScroll *event,
     pan_yaxis = FALSE;
   }
 
+#ifdef ENABLE_GTK3
+  static guint last_scroll_event_time = GDK_CURRENT_TIME;
+  /* check for duplicate legacy scroll event, see GNOME bug 726878 */
+  if (event->direction != GDK_SCROLL_SMOOTH &&
+      last_scroll_event_time == event->time) {
+    g_debug ("[%d] duplicate legacy scroll event %d\n",
+             event->time,
+             event->direction);
+    return FALSE;
+  }
+
+  switch (event->direction) {
+  case GDK_SCROLL_SMOOTH:
+    /* As of GTK 3.4, all directional scroll events are provided by */
+    /* the GDK_SCROLL_SMOOTH direction on XInput2 and Wayland devices. */
+    last_scroll_event_time = event->time;
+
+    /* event->delta_x seems to be unused on not touch devices. */
+    pan_direction = event->delta_y;
+    zoom_direction = (event->delta_y > 0) ? ZOOM_OUT : ZOOM_IN;
+    break;
+  case GDK_SCROLL_UP:
+  case GDK_SCROLL_LEFT:
+    pan_direction = -1;
+    zoom_direction = ZOOM_IN;
+    break;
+  case GDK_SCROLL_DOWN:
+  case GDK_SCROLL_RIGHT:
+    pan_direction =  1;
+    zoom_direction = ZOOM_OUT;
+    break;
+  }
+#else
   switch (event->direction) {
     case GDK_SCROLL_UP:
     case GDK_SCROLL_LEFT:
@@ -783,6 +816,7 @@ gint x_event_scroll (GtkWidget *widget, GdkEventScroll *event,
       zoom_direction = ZOOM_OUT;
       break;
   }
+#endif
 
   if (zoom) {
     /*! \todo Change "HOTKEY" TO new "MOUSE" specifier? */
@@ -854,7 +888,15 @@ x_event_get_pointer_position (GschemToplevel *w_current, gboolean snapped, gint
   width = gdk_window_get_width (window);
   height = gdk_window_get_height (window);
 
+#ifdef ENABLE_GTK3
+  GdkDisplay *display = gdk_window_get_display (window);
+  GdkSeat *seat = gdk_display_get_default_seat (display);
+  GdkDevice *pointer = gdk_seat_get_pointer (seat);
+
+  gdk_window_get_device_position (window, pointer, &sx, &sy, NULL);
+#else
   gtk_widget_get_pointer(GTK_WIDGET (page_view), &sx, &sy);
+#endif
 
   /* check if we are inside the drawing area */
   if ((sx < 0) || (sx >= width) || (sy < 0) || (sy >= height)) {
@@ -893,7 +935,18 @@ x_event_faked_motion (GschemPageView *view, GdkEventKey *event) {
   gboolean ret;
   GdkEventMotion *newevent;
 
+#ifdef ENABLE_GTK3
+  GdkWindow *window = gtk_widget_get_window (GTK_WIDGET (view));
+  g_return_val_if_fail (window != NULL, FALSE);
+
+  GdkDisplay *display = gdk_window_get_display (window);
+  GdkSeat *seat = gdk_display_get_default_seat (display);
+  GdkDevice *pointer = gdk_seat_get_pointer (seat);
+
+  gdk_window_get_device_position (window, pointer, &x, &y, NULL);
+#else
   gtk_widget_get_pointer (GTK_WIDGET (view), &x, &y);
+#endif
   newevent = (GdkEventMotion*)gdk_event_new(GDK_MOTION_NOTIFY);
   newevent->x = x;
   newevent->y = y;
