@@ -73,17 +73,20 @@ multiattrib_callback_response (GtkDialog *dialog,
 
 /*! \brief Open multiple attribute editor dialog.
  *  \par Function Description
- *  Opens the multiple attribute editor dialog for objects in this <B>toplevel</B>.
+ *  Opens the multiple attribute editor dialog for objects in this
+ *  <B>GschemToplevel</B>.
  *
  *  \param [in] w_current  The GschemToplevel object.
  */
 void
 x_multiattrib_open (GschemToplevel *w_current)
 {
+  LeptonPage *active_page = schematic_window_get_active_page (w_current);
+
   if ( w_current->mawindow == NULL ) {
     w_current->mawindow =
       GTK_WIDGET (g_object_new (TYPE_MULTIATTRIB,
-                                "object_list", w_current->toplevel->page_current->selection_list,
+                                "object_list", active_page->selection_list,
                                 /* GschemDialog */
                                 "settings-name", "multiattrib",
                                 "gschem-toplevel", w_current,
@@ -133,9 +136,12 @@ x_multiattrib_close (GschemToplevel *w_current)
 void
 x_multiattrib_update (GschemToplevel *w_current)
 {
+  LeptonPage *active_page = schematic_window_get_active_page (w_current);
+
   if (w_current->mawindow != NULL) {
-    g_object_set (G_OBJECT (w_current->mawindow), "object_list",
-                  w_current->toplevel->page_current->selection_list, NULL);
+    g_object_set (G_OBJECT (w_current->mawindow),
+                  "object_list", active_page->selection_list,
+                  NULL);
   }
 }
 
@@ -614,7 +620,7 @@ multiattrib_action_add_attribute (Multiattrib *multiattrib,
     }
   }
 
-  gschem_toplevel_page_content_changed (w_current, w_current->toplevel->page_current);
+  schematic_window_active_page_changed (w_current);
   o_undo_savestate_old (w_current, UNDO_ALL);
 
   g_free (newtext);
@@ -642,10 +648,10 @@ multiattrib_action_duplicate_attributes (Multiattrib *multiattrib,
                          lepton_text_object_get_string (o_attrib),
                          lepton_text_object_is_visible (o_attrib),
                          lepton_text_object_get_show (o_attrib),
-                         o_attrib->attached_to);
+                         lepton_object_get_attached_to (o_attrib));
   }
 
-  gschem_toplevel_page_content_changed (w_current, w_current->toplevel->page_current);
+  schematic_window_active_page_changed (w_current);
   o_undo_savestate_old (w_current, UNDO_ALL);
 }
 
@@ -659,9 +665,9 @@ multiattrib_action_promote_attributes (Multiattrib *multiattrib,
                                        GList *attr_list)
 {
   GschemToplevel *w_current = GSCHEM_DIALOG (multiattrib)->w_current;
-  LeptonToplevel *toplevel = w_current->toplevel;
   LeptonObject *o_new;
   GList *iter;
+  LeptonPage *active_page = NULL;
 
   for (iter = attr_list;
        iter != NULL;
@@ -674,13 +680,14 @@ multiattrib_action_promote_attributes (Multiattrib *multiattrib,
                            lepton_text_object_get_string (o_attrib),
                            VISIBLE,
                            lepton_text_object_get_show (o_attrib),
-                           o_attrib->parent);
+                           lepton_object_get_parent (o_attrib));
     } else {
+        active_page = schematic_window_get_active_page (w_current);
         /* make a copy of the attribute object */
         o_new = lepton_object_copy (o_attrib);
-        s_page_append (toplevel->page_current, o_new);
+        lepton_page_append (active_page, o_new);
         /* add the attribute its parent */
-        o_attrib_attach (o_new, o_attrib->parent, TRUE);
+        o_attrib_attach (o_new, lepton_object_get_parent (o_attrib), TRUE);
         /* note: this object is unselected (not added to selection). */
 
         /* Call add-objects-hook */
@@ -688,7 +695,7 @@ multiattrib_action_promote_attributes (Multiattrib *multiattrib,
     }
   }
 
-  gschem_toplevel_page_content_changed (w_current, w_current->toplevel->page_current);
+  schematic_window_active_page_changed (w_current);
   o_undo_savestate_old (w_current, UNDO_ALL);
 }
 
@@ -711,7 +718,7 @@ multiattrib_action_delete_attributes (Multiattrib *multiattrib,
     o_delete (w_current, o_attrib);
   }
 
-  gschem_toplevel_page_content_changed (w_current, w_current->toplevel->page_current);
+  schematic_window_active_page_changed (w_current);
   o_undo_savestate_old (w_current, UNDO_ALL);
 }
 
@@ -736,7 +743,8 @@ multiattrib_action_copy_attribute_to_all (Multiattrib *multiattrib,
        iter = g_list_next (iter)) {
     LeptonObject *o_attrib = (LeptonObject *)iter->data;
 
-    objects_needing_add = g_list_remove (objects_needing_add, o_attrib->attached_to);
+    objects_needing_add = g_list_remove (objects_needing_add,
+                                         lepton_object_get_attached_to (o_attrib));
   }
 
   for (iter = objects_needing_add; iter != NULL; iter = g_list_next (iter)) {
@@ -759,7 +767,7 @@ multiattrib_action_copy_attribute_to_all (Multiattrib *multiattrib,
     }
   }
 
-  gschem_toplevel_page_content_changed (w_current, w_current->toplevel->page_current);
+  schematic_window_active_page_changed (w_current);
   o_undo_savestate_old (w_current, UNDO_ALL);
 }
 
@@ -1018,7 +1026,7 @@ multiattrib_callback_edited_name (GtkCellRendererText *cellrenderertext,
   g_free (value);
   g_free (newtext);
 
-  gschem_toplevel_page_content_changed (w_current, w_current->toplevel->page_current);
+  schematic_window_active_page_changed (w_current);
   o_undo_savestate_old (w_current, UNDO_ALL);
 
   /* NB: We don't fix up the model to reflect the edit, we're about to nuke it below... */
@@ -1109,7 +1117,7 @@ multiattrib_callback_edited_value (GtkCellRendererText *cell_renderer,
   g_free (name);
   g_free (newtext);
 
-  gschem_toplevel_page_content_changed (w_current, w_current->toplevel->page_current);
+  schematic_window_active_page_changed (w_current);
   o_undo_savestate_old (w_current, UNDO_ALL);
 
   /* Fixup the model to reflect the edit */
@@ -1164,7 +1172,7 @@ multiattrib_callback_toggled_visible (GtkCellRendererToggle *cell_renderer,
 
   g_object_unref (attr_list);
 
-  gschem_toplevel_page_content_changed (w_current, w_current->toplevel->page_current);
+  schematic_window_active_page_changed (w_current);
   o_undo_savestate_old (w_current, UNDO_ALL);
 
   /* Fixup the model to reflect the edit */
@@ -1228,7 +1236,7 @@ multiattrib_callback_toggled_show_name (GtkCellRendererToggle *cell_renderer,
 
   g_object_unref (attr_list);
 
-  gschem_toplevel_page_content_changed (w_current, w_current->toplevel->page_current);
+  schematic_window_active_page_changed (w_current);
   o_undo_savestate_old (w_current, UNDO_ALL);
 
   /* NB: We don't fix up the model to reflect the edit, we're about to nuke it below... */
@@ -1292,7 +1300,7 @@ multiattrib_callback_toggled_show_value (GtkCellRendererToggle *cell_renderer,
 
   g_object_unref (attr_list);
 
-  gschem_toplevel_page_content_changed (w_current, w_current->toplevel->page_current);
+  schematic_window_active_page_changed (w_current);
   o_undo_savestate_old (w_current, UNDO_ALL);
 
   /* NB: We don't fix up the model to reflect the edit, we're about to nuke it below... */
@@ -2063,7 +2071,7 @@ static void
 multiattrib_init (Multiattrib *multiattrib)
 {
   GtkWidget *label, *scrolled_win, *treeview;
-  GtkWidget *table, *textview, *combo, *optionm, *button;
+  GtkWidget *textview, *combo, *optionm, *button;
   GtkWidget *attrib_vbox, *show_inherited;
   GtkTreeModel *store;
   GtkCellRenderer *renderer;
@@ -2287,13 +2295,16 @@ multiattrib_init (Multiattrib *multiattrib)
                       TRUE, TRUE, 1);
   gtk_widget_show_all (multiattrib->list_frame);
 
-
-  table = GTK_WIDGET (g_object_new (GTK_TYPE_TABLE,
-                                    /* GtkTable */
-                                    "n-rows",      4,
-                                    "n-columns",   2,
-                                    "homogeneous", FALSE,
-                                    NULL));
+#ifdef ENABLE_GTK3
+  GtkWidget *grid = gtk_grid_new ();
+#else
+  GtkWidget *table = GTK_WIDGET (g_object_new (GTK_TYPE_TABLE,
+                                               /* GtkTable */
+                                               "n-rows",      4,
+                                               "n-columns",   2,
+                                               "homogeneous", FALSE,
+                                               NULL));
+#endif
 
   /*   - the name entry: a GtkComboBoxEntry */
   label = gtk_label_new_with_mnemonic (_("_Name:"));
@@ -2307,6 +2318,10 @@ multiattrib_init (Multiattrib *multiattrib)
   gtk_label_set_mnemonic_widget (GTK_LABEL (label),
                                  GTK_WIDGET (multiattrib->combo_name));
 
+#ifdef ENABLE_GTK3
+  gtk_grid_attach (GTK_GRID (grid), label, 0, 0, 1, 1);
+  gtk_grid_attach (GTK_GRID (grid), combo, 1, 0, 1, 1);
+#else
   gtk_table_attach (GTK_TABLE (table), label,
                     0, 1, 0, 1,
                     (GtkAttachOptions) 0,
@@ -2317,6 +2332,7 @@ multiattrib_init (Multiattrib *multiattrib)
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) 0,
                     6, 3);
+#endif
 
   /*   - the value entry: a GtkEntry */
   label = gtk_label_new_with_mnemonic (_("_Value:"));
@@ -2388,6 +2404,10 @@ multiattrib_init (Multiattrib *multiattrib)
 
   gtk_container_add (GTK_CONTAINER (scrolled_win), textview);
   multiattrib->textview_value = GTK_TEXT_VIEW (textview);
+#ifdef ENABLE_GTK3
+  gtk_grid_attach (GTK_GRID (grid), label, 0, 1, 1, 1);
+  gtk_grid_attach (GTK_GRID (grid), scrolled_win, 1, 1, 1, 1);
+#else
   gtk_table_attach (GTK_TABLE (table), label,
                     0, 1, 1, 2,
                     (GtkAttachOptions) 0,
@@ -2398,28 +2418,38 @@ multiattrib_init (Multiattrib *multiattrib)
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) 0,
                     6, 3);
+#endif
 
   /*   - the visible status */
   button = gtk_check_button_new_with_mnemonic (_("Vi_sible"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
 
   multiattrib->button_visible = GTK_CHECK_BUTTON (button);
+#ifdef ENABLE_GTK3
+  gtk_grid_attach (GTK_GRID (grid), button, 0, 2, 1, 1);
+#else
   gtk_table_attach (GTK_TABLE (table), button,
                     0, 1, 2, 3,
                     GTK_FILL,
                     (GtkAttachOptions) 0,
                     3, 0);
+#endif
 
   /*   - the visibility type */
   optionm = gtk_combo_box_text_new ();
   multiattrib_init_visible_types (GTK_COMBO_BOX_TEXT (optionm));
   multiattrib->optionmenu_shownv = GTK_COMBO_BOX_TEXT (optionm);
+#ifdef ENABLE_GTK3
+  gtk_grid_attach (GTK_GRID (grid), optionm, 1, 2, 1, 1);
+  gtk_widget_show_all (grid);
+#else
   gtk_table_attach (GTK_TABLE (table), optionm,
                     1, 2, 2, 3,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) 0,
                     6, 3);
   gtk_widget_show_all (table);
+#endif
 
   /* create the add button */
   button = gtk_button_new_from_stock (GTK_STOCK_ADD);
@@ -2427,6 +2457,13 @@ multiattrib_init (Multiattrib *multiattrib)
                     "clicked",
                     G_CALLBACK (multiattrib_callback_button_add),
                     multiattrib);
+#ifdef ENABLE_GTK3
+  gtk_grid_attach (GTK_GRID (grid), button, 2, 0, 1, 1);
+
+  multiattrib->add_frame =
+    gschem_dialog_misc_create_section_widget(
+      _("<b>Add Attribute</b>"), grid);
+#else
   gtk_table_attach (GTK_TABLE (table), button,
                     2, 3, 0, 3,
                     (GtkAttachOptions) 0,
@@ -2437,6 +2474,7 @@ multiattrib_init (Multiattrib *multiattrib)
   multiattrib->add_frame =
     gschem_dialog_misc_create_section_widget(
       _("<b>Add Attribute</b>"), table);
+#endif
 
   g_signal_connect (multiattrib->add_frame,
                     "activate",
@@ -2562,7 +2600,8 @@ object_attributes_to_model_rows (Multiattrib *multiattrib, LeptonObject *object)
     GList *m_iter;
 
     m_row->inherited = o_attrib_is_inherited (a_current);
-    o_attrib_get_name_value (a_current, &m_row->name, &m_row->value);
+    m_row->name  = g_strdup (lepton_text_object_get_name (a_current));
+    m_row->value = g_strdup (lepton_text_object_get_value (a_current));
     m_row->visibility = lepton_text_object_is_visible (a_current);
     m_row->show_name_value = lepton_text_object_get_show (a_current);
     m_row->nth_with_name = 0; /* Provisional value until we check below */
@@ -2624,17 +2663,17 @@ lone_attributes_to_model_rows (Multiattrib *multiattrib)
     MODEL_ROW *m_row;
 
     /* Consider a selected text object might be an attribute */
-    if (!lepton_object_is_text (object) ||
-        !o_attrib_is_attrib (object))
+    if (!lepton_object_is_attrib (object))
       continue;
 
-    /* We have an OBJ_TEXT which libgeda can parse as an attribute */
+    /* We have an attribute object. */
 
     multiattrib->num_lone_attribs_in_list ++;
 
     m_row = g_new0 (MODEL_ROW, 1);
     m_row->inherited = o_attrib_is_inherited (object);
-    o_attrib_get_name_value (object, &m_row->name, &m_row->value);
+    m_row->name = g_strdup (lepton_text_object_get_name (object));
+    m_row->value = g_strdup (lepton_text_object_get_value (object));
     m_row->visibility = lepton_text_object_is_visible (object);
     m_row->show_name_value = lepton_text_object_get_show (object);
     m_row->nth_with_name = 0; /* All selected attributes are treated individually */
@@ -2827,8 +2866,9 @@ multiattrib_update (Multiattrib *multiattrib)
       multiattrib->num_comp_in_list++;
 
       if (component_title_name == NULL)
-        component_title_name = object->component_basename;
-      else if (strcmp (component_title_name, object->component_basename) != 0)
+        component_title_name = lepton_component_object_get_basename (object);
+      else if (strcmp (component_title_name,
+                       lepton_component_object_get_basename (object)) != 0)
         component_title_name = _("<various>");
     }
 
