@@ -55,7 +55,6 @@
  * be LANDSCAPE, PORTRAIT or AUTOLAYOUT.  If \a AUTOLAYOUT is chosen,
  * the page orientation that best fits the page contents is chosen.
  *
- * \param toplevel A #LeptonToplevel structure.
  * \param page     The #LeptonPage to generate a page setup for.
  * \param paper_size_name   The name of the paper size to use.
  * \param orientation       The paper orientation to use.
@@ -63,8 +62,7 @@
  * \returns A newly-created page setup.
  */
 static GtkPageSetup *
-x_print_default_page_setup (LeptonToplevel *toplevel,
-                            LeptonPage *page)
+x_print_default_page_setup (LeptonPage *page)
 {
   GtkPageSetup *setup = gtk_page_setup_new ();
   GtkPaperSize *papersize;
@@ -73,7 +71,7 @@ x_print_default_page_setup (LeptonToplevel *toplevel,
   gchar *paper, *orientation;
 
   /* Get configuration values */
-  cfg =         eda_config_get_context_for_path (s_page_get_filename (page));
+  cfg = eda_config_get_context_for_path (lepton_page_get_filename (page));
   paper =       eda_config_get_string (cfg, CFG_GROUP_PRINTING,
                                        CFG_KEY_PRINTING_PAPER, NULL);
   orientation = eda_config_get_string (cfg, CFG_GROUP_PRINTING,
@@ -92,7 +90,7 @@ x_print_default_page_setup (LeptonToplevel *toplevel,
   } else if (orientation == NULL
              || g_strcmp0 (orientation, "auto") == 0) {
     /* Automatically choose the orientation that fits best */
-    status = world_get_object_glist_bounds (s_page_objects (page),
+    status = world_get_object_glist_bounds (lepton_page_objects (page),
                                             /* Don't include hidden objects */
                                             FALSE,
                                             &wx_min, &wy_min, &wx_max, &wy_max);
@@ -118,7 +116,6 @@ x_print_default_page_setup (LeptonToplevel *toplevel,
  * is_raster should be set if drawing to a raster surface such as an
  * image.
  *
- * \param toplevel A #LeptonToplevel structure.
  * \param page     The #LeptonPage to be rendered.
  * \param cr       The Cairo context to render to.
  * \param pc       A Pango context for text rendering, or NULL.
@@ -128,8 +125,7 @@ x_print_default_page_setup (LeptonToplevel *toplevel,
  * \param is_raster TRUE if drawing to a raster image surface; FALSE otherwise.
  */
 static void
-x_print_draw_page (LeptonToplevel *toplevel,
-                   LeptonPage *page,
+x_print_draw_page (LeptonPage *page,
                    cairo_t *cr,
                    PangoContext *pc,
                    double cr_width,
@@ -147,7 +143,7 @@ x_print_draw_page (LeptonToplevel *toplevel,
   /* First, calculate a transformation matrix for the cairo
    * context. We want to center the extents of the page in the
    * available page area. */
-  status = world_get_object_glist_bounds (s_page_objects (page),
+  status = world_get_object_glist_bounds (lepton_page_objects (page),
                                           /* Don't include hidden objects. */
                                           FALSE,
                                           &wx_min,
@@ -217,12 +213,12 @@ x_print_draw_page (LeptonToplevel *toplevel,
   cairo_paint (cr);
 
   /* Draw all objects and cues */
-  for (iter = (GList *) s_page_objects (page);
+  for (iter = (GList *) lepton_page_objects (page);
        iter != NULL;
        iter = g_list_next (iter)) {
     eda_renderer_draw (renderer, (LeptonObject *) iter->data);
   }
-  for (iter = (GList *) s_page_objects (page);
+  for (iter = (GList *) lepton_page_objects (page);
        iter != NULL;
        iter = g_list_next (iter)) {
     eda_renderer_draw_cues (renderer, (LeptonObject *) iter->data);
@@ -251,7 +247,7 @@ draw_page__print_operation (GtkPrintOperation *print,
 
   /* Find the page data */
   g_return_if_fail (page_nr != 1);
-  page = w_current->toplevel->page_current;
+  page = schematic_window_get_active_page (w_current);
   g_return_if_fail (page != NULL);
 
   /* Get cairo & pango contexts */
@@ -262,11 +258,11 @@ draw_page__print_operation (GtkPrintOperation *print,
   height = gtk_print_context_get_height (context);
 
   /* Find out if colour printing is enabled */
-  cfg = eda_config_get_context_for_path (s_page_get_filename (page));
+  cfg = eda_config_get_context_for_path (lepton_page_get_filename (page));
   is_color = !eda_config_get_boolean (cfg, CFG_GROUP_PRINTING,
                                       CFG_KEY_PRINTING_MONOCHROME, NULL);
 
-  x_print_draw_page (w_current->toplevel, page, cr, pc,
+  x_print_draw_page (page, cr, pc,
                      width, height, is_color, FALSE);
 
   /* Clean up */
@@ -297,9 +293,9 @@ x_print_export_pdf_page (GschemToplevel *w_current,
   EdaConfig *cfg;
   gboolean is_color;
 
-  page = w_current->toplevel->page_current;
+  page = schematic_window_get_active_page (w_current);
 
-  setup = x_print_default_page_setup (w_current->toplevel, page );
+  setup = x_print_default_page_setup (page);
   width = gtk_page_setup_get_paper_width (setup, GTK_UNIT_POINTS);
   height = gtk_page_setup_get_paper_height (setup, GTK_UNIT_POINTS);
 
@@ -312,12 +308,11 @@ x_print_export_pdf_page (GschemToplevel *w_current,
   height = gtk_page_setup_get_page_height (setup, GTK_UNIT_POINTS);
 
   /* Find out if colour printing is enabled */
-  cfg = eda_config_get_context_for_path (s_page_get_filename (page));
+  cfg = eda_config_get_context_for_path (lepton_page_get_filename (page));
   is_color = !eda_config_get_boolean (cfg, CFG_GROUP_PRINTING,
                                       CFG_KEY_PRINTING_MONOCHROME, NULL);
 
-  x_print_draw_page (w_current->toplevel, page,
-                     cr, NULL, width, height, is_color, FALSE);
+  x_print_draw_page (page, cr, NULL, width, height, is_color, FALSE);
 
   cairo_destroy (cr);
   cairo_surface_finish (surface);
@@ -358,10 +353,12 @@ x_print_export_pdf (GschemToplevel *w_current,
   int status, wx_min, wy_min, wx_max, wy_max;
   double width, height;
 
+  LeptonPage *active_page = schematic_window_get_active_page (w_current);
+
   /* First, calculate a transformation matrix for the cairo
    * context. We want to center the extents of the page in the
    * available page area. */
-  status = world_get_object_glist_bounds (s_page_objects (w_current->toplevel->page_current),
+  status = world_get_object_glist_bounds (lepton_page_objects (active_page),
                                           /* Don't include hidden objects. */
                                           FALSE,
                                           &wx_min, &wy_min, &wx_max, &wy_max);
@@ -376,7 +373,7 @@ x_print_export_pdf (GschemToplevel *w_current,
   surface = cairo_pdf_surface_create (filename, width, height);
   cr = cairo_create (surface);
 
-  x_print_draw_page (w_current->toplevel, w_current->toplevel->page_current,
+  x_print_draw_page (active_page,
                      cr, NULL, width, height,
                      is_color, FALSE);
 
@@ -412,6 +409,8 @@ x_print (GschemToplevel *w_current)
   GError *err = NULL;
   const int num_pages = 1;
 
+  LeptonPage *active_page = schematic_window_get_active_page (w_current);
+
   /* Create the print operation and set it up */
   print = GTK_PRINT_OPERATION (g_object_new (GTK_TYPE_PRINT_OPERATION,
                                              "n-pages", num_pages,
@@ -419,8 +418,7 @@ x_print (GschemToplevel *w_current)
                                              "unit", GTK_UNIT_POINTS,
                                              NULL));
 
-  setup = x_print_default_page_setup (w_current->toplevel,
-                                      w_current->toplevel->page_current);
+  setup = x_print_default_page_setup (active_page);
   gtk_print_operation_set_default_page_setup (print, setup);
 
   g_signal_connect (print, "draw_page", G_CALLBACK (draw_page__print_operation),
@@ -443,10 +441,9 @@ x_print (GschemToplevel *w_current)
 
   /* derive output file name from the file name of the current page:
   */
-  LeptonPage* page = w_current->toplevel->page_current;
-  if (page != NULL)
+  if (active_page != NULL)
   {
-    const gchar* path = s_page_get_filename (page);
+    const gchar* path = lepton_page_get_filename (active_page);
     gchar* uri = g_strdup_printf ("file://%s.pdf", path);
 
     gtk_print_settings_set (settings, "output-uri", uri);
