@@ -420,7 +420,8 @@ x_tabs_dbg_pages_dump_simple (GschemToplevel* w_current)
         node = g_list_next( node ) )
   {
     LeptonPage* p = node->data;
-    printf( "    p: [%s]\n", g_path_get_basename( s_page_get_filename(p) ) );
+    printf ("    p: [%s]\n",
+            g_path_get_basename (lepton_page_get_filename (p)));
   }
 
   printf( "\n" );
@@ -575,7 +576,7 @@ x_tabs_info_find_by_wtab (GList* nfos, GtkWidget* wtab)
 static LeptonPage*
 x_tabs_tl_page_cur (GschemToplevel* w_current)
 {
-  return w_current->toplevel->page_current;
+  return schematic_window_get_active_page (w_current);
 }
 
 
@@ -584,9 +585,10 @@ static void
 x_tabs_tl_page_cur_set (GschemToplevel* w_current,
                         LeptonPage* page)
 {
-  s_page_goto (w_current->toplevel, page);
+  lepton_toplevel_goto_page (w_current->toplevel, page);
 
-  /* NOTE: gschem_toplevel_page_changed() after s_page_goto():
+  /* NOTE: gschem_toplevel_page_changed() after
+   * lepton_toplevel_goto_page():
   */
   gschem_toplevel_page_changed (w_current);
 }
@@ -834,13 +836,13 @@ x_tabs_hdr_create (TabInfo* nfo)
 
   /* label:
   */
-  const gchar* fname = s_page_get_filename (nfo->page_);
+  const gchar* fname = lepton_page_get_filename (nfo->page_);
   g_return_val_if_fail (fname != NULL, NULL);
 
   gchar* bname = g_path_get_basename (fname);
   gchar* lab_txt = NULL;
 
-  if (nfo->page_->CHANGED)
+  if (lepton_page_get_changed (nfo->page_))
     lab_txt = g_strdup_printf ("<b>%s</b>", bname);
   else
     lab_txt = g_strdup (bname);
@@ -949,7 +951,7 @@ x_tabs_hdr_create (TabInfo* nfo)
 
   /* setup "save" btn:
   */
-  if (nfo->page_->CHANGED)
+  if (lepton_page_get_changed (nfo->page_))
   {
     gtk_box_pack_end (GTK_BOX (box_btns_left), btn_save, FALSE, FALSE, 0);
 
@@ -962,12 +964,11 @@ x_tabs_hdr_create (TabInfo* nfo)
 
   /* setup "up" btn:
   */
-  LeptonToplevel* toplevel = gschem_toplevel_get_toplevel (nfo->tl_);
-  LeptonPage* parent = s_hierarchy_find_up_page (toplevel->pages, nfo->page_);
+  LeptonPage* parent = s_hierarchy_find_up_page (nfo->page_);
 
   if (x_tabs_show_up_button() && parent != NULL)
   {
-    const gchar* parent_fname = s_page_get_filename (parent);
+    const gchar* parent_fname = lepton_page_get_filename (parent);
     gchar*       parent_bname = NULL;
     gchar*       ttip_btn_up  = NULL;
 
@@ -1071,7 +1072,7 @@ x_tabs_hdr_on_btn_close (GtkToolButton* btn, gpointer p)
   {
     x_tabs_page_set_cur (nfo->tl_, nfo->page_);
 
-    if (nfo->page_->CHANGED)
+    if (lepton_page_get_changed (nfo->page_))
     {
       if (!x_dialog_close_changed_page (nfo->tl_, nfo->page_))
       {
@@ -1159,11 +1160,11 @@ x_tabs_cancel_all (GschemToplevel* w_current)
     o_grips_cancel (w_current);
   }
 
-  LeptonToplevel* toplevel = gschem_toplevel_get_toplevel (w_current);
-  if (toplevel->page_current != NULL)
+  LeptonPage *active_page = schematic_window_get_active_page (w_current);
+  if (active_page != NULL)
   {
-    lepton_object_list_delete (toplevel->page_current->place_list);
-    toplevel->page_current->place_list = NULL;
+    lepton_object_list_delete (active_page->place_list);
+    active_page->place_list = NULL;
   }
 
   i_set_state (w_current, SELECT);
@@ -1188,15 +1189,14 @@ x_tabs_cancel_all (GschemToplevel* w_current)
 static void
 x_tabs_hier_up (GschemToplevel* w_current)
 {
-  LeptonToplevel* toplevel = gschem_toplevel_get_toplevel (w_current);
-  LeptonPage* page = toplevel->page_current;
+  LeptonPage* page = schematic_window_get_active_page (w_current);
 
   if (page == NULL)
   {
     return;
   }
 
-  LeptonPage* parent = s_hierarchy_find_up_page (toplevel->pages, page);
+  LeptonPage* parent = s_hierarchy_find_up_page (page);
 
   if (parent == NULL)
   {
@@ -1204,7 +1204,7 @@ x_tabs_hier_up (GschemToplevel* w_current)
     return;
   }
 
-  if (page->CHANGED)
+  if (lepton_page_get_changed (page))
   {
     if (!x_dialog_close_changed_page (w_current, page))
     {
@@ -1378,7 +1378,7 @@ x_tabs_page_open (GschemToplevel* w_current, const gchar* filename)
 
   LeptonPage* page = NULL;
   if (filename != NULL)
-    page = s_page_search (w_current->toplevel, filename);
+    page = lepton_toplevel_search_page (w_current->toplevel, filename);
 
 
   /* XXX: 2: [!pview] [!page] - either:
@@ -1704,8 +1704,8 @@ x_tabs_hdr_on_mouse_click (GtkWidget* hdr, GdkEvent* e, gpointer data)
   }
 
 #ifdef DEBUG
-  printf( "p: [%s]\n",   g_path_get_basename( s_page_get_filename(nfo->page_) ) );
-  printf( "C: [%s]\n\n", g_path_get_basename( s_page_get_filename(nfocur->page_) ) );
+  printf ("p: [%s]\n",   g_path_get_basename (lepton_page_get_filename(nfo->page_)));
+  printf ("C: [%s]\n\n", g_path_get_basename (lepton_page_get_filename(nfocur->page_)));
 #endif
 
   GdkEventButton* ebtn = (GdkEventButton*) e;
