@@ -121,7 +121,7 @@ x_window_setup (GschemToplevel *w_current)
   i_vars_set(w_current);
 
   /* Initialize the autosave callback */
-  s_page_autosave_init(toplevel);
+  lepton_toplevel_init_autosave (toplevel);
 
   /* Initialize the clipboard callback */
   x_clipboard_init (w_current);
@@ -139,7 +139,7 @@ x_window_setup (GschemToplevel *w_current)
  */
 void x_window_create_drawing(GtkWidget *scrolled, GschemToplevel *w_current)
 {
-  LeptonPage* page = w_current->toplevel->page_current;
+  LeptonPage* page = schematic_window_get_active_page (w_current);
   GschemPageView* view = gschem_page_view_new_with_page (page);
 
 #ifdef ENABLE_GTK3
@@ -248,6 +248,9 @@ void x_window_setup_draw_events_drawing_area (GschemToplevel* w_current,
                          GDK_EXPOSURE_MASK |
                          GDK_POINTER_MOTION_MASK |
                          GDK_BUTTON_PRESS_MASK   |
+#if GTK_CHECK_VERSION(3,4,0)
+                         GDK_SMOOTH_SCROLL_MASK |
+#endif
                          GDK_ENTER_NOTIFY_MASK |
                          GDK_KEY_PRESS_MASK |
                          GDK_BUTTON_RELEASE_MASK
@@ -352,12 +355,14 @@ x_window_find_text (GtkWidget *widget, gint response, GschemToplevel *w_current)
 static void
 x_window_hide_text (GtkWidget *widget, gint response, GschemToplevel *w_current)
 {
+  LeptonPage *page = NULL;
+
   g_return_if_fail (w_current != NULL);
-  g_return_if_fail (w_current->toplevel != NULL);
 
   if (response == GTK_RESPONSE_OK) {
+    page = schematic_window_get_active_page (w_current);
     o_edit_hide_specific_text (w_current,
-                               s_page_objects (w_current->toplevel->page_current),
+                               lepton_page_objects (page),
                                gschem_show_hide_text_widget_get_text_string (GSCHEM_SHOW_HIDE_TEXT_WIDGET (widget)));
   }
 
@@ -369,12 +374,14 @@ x_window_hide_text (GtkWidget *widget, gint response, GschemToplevel *w_current)
 static void
 x_window_show_text (GtkWidget *widget, gint response, GschemToplevel *w_current)
 {
+  LeptonPage *page = NULL;
+
   g_return_if_fail (w_current != NULL);
-  g_return_if_fail (w_current->toplevel != NULL);
 
   if (response == GTK_RESPONSE_OK) {
+    page = schematic_window_get_active_page (w_current);
     o_edit_show_specific_text (w_current,
-                               s_page_objects (w_current->toplevel->page_current),
+                               lepton_page_objects (page),
                                gschem_show_hide_text_widget_get_text_string (GSCHEM_SHOW_HIDE_TEXT_WIDGET (widget)));
   }
 
@@ -538,8 +545,13 @@ x_window_create_main (GschemToplevel *w_current, GtkWidget *menubar)
   /*
   *  windows layout:
   */
+#ifdef ENABLE_GTK3
+  vpaned = gtk_paned_new (GTK_ORIENTATION_VERTICAL);
+  hpaned = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
+#else
   vpaned = gtk_vpaned_new ();
   hpaned = gtk_hpaned_new ();
+#endif
 
   w_current->right_notebook = create_notebook_right (w_current);
   w_current->bottom_notebook = create_notebook_bottom (w_current);
@@ -733,16 +745,16 @@ x_window_open_page_impl (GschemToplevel *w_current,
 
 
   /* Return existing page if it is already loaded: */
-  LeptonPage* page = s_page_search (toplevel, filename);
+  LeptonPage* page = lepton_toplevel_search_page (toplevel, filename);
   if (page != NULL)
     return page;
 
 
   /* Create a new page: */
-  page = s_page_new (toplevel, filename);
+  page = lepton_page_new (toplevel, filename);
 
   /* Switch to a new page: */
-  s_page_goto (toplevel, page); /* NOTE: sets toplevel->page_current */
+  lepton_toplevel_goto_page (toplevel, page); /* NOTE: sets current active page of toplevel */
   gschem_toplevel_page_changed (w_current);
 
   if (!quiet_mode)
@@ -758,7 +770,7 @@ x_window_open_page_impl (GschemToplevel *w_current,
     g_clear_error (&err);
 
     /* Loading failed: delete page and open a blank one: */
-    s_page_delete (toplevel, page);
+    lepton_page_delete (toplevel, page);
     return x_window_new_page (w_current);
   }
 
@@ -862,8 +874,9 @@ x_window_save_page (GschemToplevel *w_current,
   } else {
     /* successful save of page to file, update page... */
     /* change page name if necessary and prepare log message */
-    if (g_ascii_strcasecmp (s_page_get_filename (page), filename) != 0) {
-      s_page_set_filename (page, filename);
+    if (g_ascii_strcasecmp (lepton_page_get_filename (page), filename) != 0)
+    {
+      lepton_page_set_filename (page, filename);
 
       log_msg = _("Saved as [%1$s]");
     } else {
@@ -872,7 +885,7 @@ x_window_save_page (GschemToplevel *w_current,
     state_msg = _("Saved");
 
     /* reset page CHANGED flag */
-    page->CHANGED = 0;
+    lepton_page_set_changed (page, 0);
 
     /* add to recent file list */
     recent_manager_add (w_current, filename);
@@ -925,10 +938,11 @@ x_window_close_page_impl (GschemToplevel *w_current,
     i_callback_cancel (NULL, w_current);
   }
 
-  if (page == toplevel->page_current) {
+  if (page == lepton_toplevel_get_page_current (toplevel))
+  {
     /* as it will delete current page, select new current page */
     /* first look up in page hierarchy */
-    new_current = s_page_search_by_page_id (toplevel->pages, page->up);
+    new_current = lepton_toplevel_search_page_by_id (toplevel->pages, page->up);
 
     if (new_current == NULL) {
       /* no up in hierarchy, choice is prev, next, new page */
@@ -946,15 +960,15 @@ x_window_close_page_impl (GschemToplevel *w_current,
     /* new_current will be the new current page at the end of the function */
   }
 
-  g_message (page->CHANGED ?
+  g_message (lepton_page_get_changed (page) ?
              _("Discarding page [%1$s]") : _("Closing [%1$s]"),
-             s_page_get_filename (page));
+             lepton_page_get_filename (page));
   /* remove page from toplevel list of page and free */
-  s_page_delete (toplevel, page);
+  lepton_page_delete (toplevel, page);
   gschem_toplevel_page_changed (w_current);
 
   /* Switch to a different page if we just removed the current */
-  if (toplevel->page_current == NULL)
+  if (lepton_toplevel_get_page_current (toplevel) == NULL)
   {
 
     /* Create a new page if there wasn't another to switch to */
@@ -1554,10 +1568,10 @@ x_window_new_page (GschemToplevel* w_current)
   gchar* filename = untitled_filename (w_current, TRUE);
 
   /* Create a new page: */
-  LeptonPage* page = s_page_new (toplevel, filename);
+  LeptonPage* page = lepton_page_new (toplevel, filename);
 
   /* Switch to a new page: */
-  s_page_goto (toplevel, page);
+  lepton_toplevel_goto_page (toplevel, page);
   gschem_toplevel_page_changed (w_current);
 
   if (!quiet_mode)
@@ -1704,7 +1718,7 @@ untitled_filename (GschemToplevel* w_current, gboolean log_skipped)
     /* Avoid reusing names of already opened files:
     *  Avoid reusing names of existing files in current directory:
     */
-    if ( s_page_search_by_basename (toplevel, fname) ||
+    if ( lepton_toplevel_search_page_by_basename (toplevel, fname) ||
          g_file_test (fpath, G_FILE_TEST_EXISTS) )
     {
       if (log_skipped)
@@ -1746,7 +1760,7 @@ x_window_untitled_page (LeptonPage* page)
 {
   g_return_val_if_fail (page != NULL, TRUE);
 
-  const gchar* fname = s_page_get_filename (page);
+  const gchar* fname = lepton_page_get_filename (page);
   gchar* uname = NULL;
 
   EdaConfig* cfg = eda_config_get_context_for_path (fname);
