@@ -1,5 +1,4 @@
 #!/usr/bin/env sh
-export GUILE_LOAD_COMPILED_PATH="@ccachedir@:${GUILE_LOAD_COMPILED_PATH}"
 exec @GUILE@ "$0" "$@"
 !#
 
@@ -13,7 +12,8 @@ exec @GUILE@ "$0" "$@"
 
 (eval-when (expand load eval)
   (unless (getenv "LIBLEPTON")
-    (add-to-load-path "@LEPTON_SCHEME_MODULE_DIRECTORY@")))
+    (add-to-load-path "@LEPTON_SCHEME_MODULE_DIRECTORY@")
+    (set! %load-compiled-path (cons "@ccachedir@" %load-compiled-path))))
 
 (use-modules (ice-9 format)
              (ice-9 getopt-long)
@@ -21,6 +21,9 @@ exec @GUILE@ "$0" "$@"
 
 ;; Initialize liblepton library.
 (liblepton_init)
+(unless (getenv "LEPTON_INHIBIT_RC_FILES")
+  (register-data-dirs))
+(edascm_init)
 
 ( primitive-eval '(use-modules (lepton core toplevel)) )
 ( primitive-eval '(use-modules (lepton object)) )
