@@ -1,5 +1,4 @@
 #!/bin/sh
-export GUILE_LOAD_COMPILED_PATH="@ccachedir@:${GUILE_LOAD_COMPILED_PATH}"
 exec @GUILE@ "$0" "$@"
 !#
 
@@ -13,7 +12,8 @@ exec @GUILE@ "$0" "$@"
 
 (eval-when (expand load eval)
   (unless (getenv "LIBLEPTON")
-    (add-to-load-path "@LEPTON_SCHEME_MODULE_DIRECTORY@")))
+    (add-to-load-path "@LEPTON_SCHEME_MODULE_DIRECTORY@")
+    (set! %load-compiled-path (cons "@ccachedir@" %load-compiled-path))))
 
 (use-modules (ice-9 format)
              (ice-9 rdelim) ; read-line()
@@ -22,6 +22,9 @@ exec @GUILE@ "$0" "$@"
 
 ;; Initialize liblepton library.
 (liblepton_init)
+(unless (getenv "LEPTON_INHIBIT_RC_FILES")
+  (register-data-dirs))
+(edascm_init)
 
 ; Avoid Scheme compile-time errors using a clever trick
 ; from netlist/scheme/lepton-netlist.scm (see comments there):
